library(doBy)
library(dplyr)
library(reshape2)
library(nlme)
library(lattice)
library(MuMIn)
library(multcomp)
library(effects)
library(emmeans)
library(lsmeans)
library(stargazer)
library(ggplot2)
library(xlsx)

#############################  attach data  #############################

library(readxl)
Data_Achilles_et_al_2021 <- read_excel("Data_Achilles_et_al_2021.xlsx", 
                                       col_types = c("text", "text", "numeric", 
                                                     "text", "numeric", "numeric", "numeric", 
                                                     "numeric", "numeric", "numeric", 
                                                     "numeric", "numeric", "numeric", 
                                                     "numeric", "numeric"))
View(Data_Achilles_et_al_2021)

library(readxl)
SpecDat_SF <- read_excel("./SpecDat_SF.xlsx", 
                         col_types = c("text", "text", "text", 
                                       "numeric", "numeric", "numeric", 
                                       "numeric", "numeric", "numeric", 
                                       "numeric", "numeric", "numeric", 
                                       "numeric", "numeric"))
View(SpecDat_SF)
attach(SpecDat_SF)

SpecDat_FAL <- read_excel("./SpecDat_FAL.xlsx", 
                          col_types = c("text", "text", "numeric", 
                                        "numeric", "numeric", "numeric", 
                                        "numeric", "numeric", "numeric", 
                                        "numeric", "numeric", "numeric", 
                                        "numeric", "numeric"))
View(SpecDat_FAL)
attach(SpecDat_FAL)

SpecDat_Lit <- read_excel("./SpecDat_Lit.xlsx", 
                          col_types = c("text", "text", "text", 
                                        "numeric", "numeric", "numeric", 
                                        "numeric", "numeric", "numeric"))
View(SpecDat_Lit)
attach(SpecDat_Lit)


##############################  in-depth data exploration #################################

##############################  summary statistic #########################################

library(doBy)
summary.SpecDat_SF <- as.data.frame(summaryBy(.~ Type, data = SpecDat_SF, FUN=c(min, max, mean, sd, median, mad, IQR), na.rm=TRUE))
summary.SpecDat_SF
write.xlsx(summary.SpecDat_SF, "./output/summary_statistics.xlsx", sheetName="Summary_SpecDat_SF", 
           col.names=TRUE, row.names=TRUE, append=TRUE, showNA=TRUE, password=NULL)   

summary.SpecDat_SF <- as.data.frame(summaryBy(.~ Type| Site, data = SpecDat_SF, FUN=c(min, max, mean, sd, median, mad, IQR), na.rm=TRUE))
summary.SpecDat_SF
write.xlsx(summary.SpecDat_SF, "./output/summary_statistics.xlsx", sheetName="Summary_SpecDat_SF_Site", 
           col.names=TRUE, row.names=TRUE, append=TRUE, showNA=TRUE, password=NULL)   

summary.SpecDat_FAL <- as.data.frame(summaryBy(.~ Type, data = SpecDat_FAL, FUN=c(min, max, mean, sd, median, mad, IQR), na.rm=TRUE))
summary.SpecDat_FAL
write.xlsx(summary.SpecDat_FAL, "./output/summary_statistics.xlsx", sheetName="Summary_SpecDat_FAL", 
           col.names=TRUE, row.names=TRUE, append=TRUE, showNA=TRUE, password=NULL)   

summary.SpecDat_FAL <- as.data.frame(summaryBy(.~ Type| Site, data = SpecDat_FAL, FUN=c(min, max, mean, sd, median, mad, IQR), na.rm=TRUE))
summary.SpecDat_FAL
write.xlsx(summary.SpecDat_FAL, "./output/summary_statistics.xlsx", sheetName="Summary_SpecDat_FAL_Site", 
           col.names=TRUE, row.names=TRUE, append=TRUE, showNA=TRUE, password=NULL) 

summary.SpecDat_Lit <- as.data.frame(summaryBy(.~ Type, data = SpecDat_Lit, FUN=c(min, max, mean, sd, median, mad, IQR), na.rm=TRUE))
summary.SpecDat_Lit
write.xlsx(summary.SpecDat_Lit, "./output/summary_statistics.xlsx", sheetName="Summary_SpecDat_Lit", 
           col.names=TRUE, row.names=TRUE, append=TRUE, showNA=TRUE, password=NULL)   

summary.SpecDat_Lit <- as.data.frame(summaryBy(.~ Type| Site, data = SpecDat_Lit, FUN=c(min, max, mean, sd, median, mad, IQR), na.rm=TRUE))
summary.SpecDat_Lit
write.xlsx(summary.SpecDat_FAL, "./output/summary_statistics.xlsx", sheetName="Summary_SpecDat_Lit_Site", 
           col.names=TRUE, row.names=TRUE, append=TRUE, showNA=TRUE, password=NULL) 


##############################  boxplot by Type ##########################################

#boxplot ggplot reshape data (.m)
library(readxl)
SpecDat_SF_m <- read_excel("./SpecDat_SF.m.xlsx", 
                           col_types = c("text", "text", "text", 
                                         "text", "numeric"))
View(SpecDat_SF_m)
attach(SpecDat_SF_m)


library(readxl)
SpecDat_FAL_m <- read_excel("./SpecDat_FAL.m.xlsx", 
                            col_types = c("text", "text", "text", 
                                          "numeric"))
View(SpecDat_FAL_m)
attach(SpecDat_FAL_m)


library(readxl)
SpecDat_Lit_m <- read_excel("./SpecDat_Lit.m.xlsx", 
                            col_types = c("text", "text", "text", 
                                          "text", "numeric"))
View(SpecDat_Lit_m)
attach(SpecDat_Lit_m)

# boxplot per variable, add dots
library(ggplot2)
ggplot(SpecDat_SF_m, aes(x= Type, y=Value, fill=Type)) +
  geom_boxplot() +
  geom_point(position=position_jitterdodge(),width=0.05, alpha=0.1) +
  facet_wrap(~Variable, scale="free")
ggsave("./output/boxSpecDat_SF.jpeg", width = 10, height = 14, dpi=800)

library(ggplot2)
ggplot(SpecDat_FAL_m, aes(x= Type, y=Value, fill=Type)) +
  geom_boxplot() +
  geom_point(position=position_jitterdodge(),width=0.05, alpha=0.1) +
  facet_wrap(~Variable, scale="free")
ggsave("./output/boxSpecDat_FAL.jpeg", width = 10, height = 14, dpi=800)

library(ggplot2)
ggplot(SpecDat_Lit_m, aes(x= Type, y=Value, fill=Type)) +
  geom_boxplot() +
  geom_point(position=position_jitterdodge(),width=0.05, alpha=0.1) +
  facet_wrap(~Variable, scale="free")
ggsave("./output/boxSpecDat_Lit.jpeg", width = 10, height = 14, dpi=800)


##############################  boxplot by Type and Site #################################
#boxplot per variable, splitted up by Site
library(ggplot2)
ggplot(SpecDat_SF_m, aes(x= Type, y=Value, fill=Site)) +
  geom_boxplot() +
  geom_point(position=position_jitterdodge(),width=0.05, alpha=0.1) +
  facet_wrap(~Variable, scale="free")
ggsave("./output/boxSpecDat_SF_Site.jpeg", width = 10, height = 14, dpi=800)

library(ggplot2)
ggplot(SpecDat_Lit_m, aes(x= Type, y=Value, fill=Site)) +
  geom_boxplot() +
  geom_point(position=position_jitterdodge(),width=0.05, alpha=0.1) +
  facet_wrap(~Variable, scale="free")
ggsave("./output/boxSpecDat_Lit_Site.jpeg", width = 10, height = 14, dpi=800)

library(ggplot2)
ggplot(SpecDat_FAL_m, aes(x= Type, y=Value, fill=Site)) +
  geom_dotplot(binaxis='y') +
  facet_wrap(~Variable, scale="free")
ggsave("./output/dotSpecDat_FAL_Site.jpeg", width = 10, height = 14, dpi=800)


##############################  correlation with pair plot ################################
library(GGally)
library(readxl)

X_SF<-SpecDat_SF[,4:14]
ggpairs(X_SF) 
ggpairs(X_SF, aes(colour = as.factor(SpecDat_SF$Type), alpha = 0.5), upper = list(continuous = wrap("cor", size = 4.4, fontface = "bold")))
ggsave("./output/corSpecDat_SF.jpeg", width = 16, height = 12, dpi=1200)

X_FAL<-SpecDat_FAL[,3:14]
ggpairs(X_FAL) 
ggpairs(X_FAL, aes(colour = as.factor(SpecDat_FAL$Type), alpha = 0.5), upper = list(continuous = wrap("cor", size = 4.4, fontface = "bold")))
ggsave("./output/corSpecDat_FAL.jpeg", width = 16, height = 12, dpi=1200)

X_Lit<-SpecDat_Lit[,4:9]
ggpairs(X_Lit) 
ggpairs(X_Lit, aes(colour = as.factor(SpecDat_Lit$Type), alpha = 0.5), upper = list(continuous = wrap("cor", size = 4.4, fontface = "bold")))
ggsave("./output/corSpecDat_Lit.jpeg", width = 16, height = 12, dpi=1200)

# correlation plot Floor 2001-2018
datacorFL <- read_excel("./correlationFL.xlsx")
View(datacorFL)

X<-datacorFL[,4:11]
ggpairs(X) 
ggpairs(X, aes(colour = as.factor(datacorFL$Type), alpha = 0.5), 
        upper = list(continuous = wrap("cor", size = 4.4, 
                                       fontface = "bold"))) + scale_color_manual(values=c("grey70", "grey29")) + scale_fill_manual(values=c("grey70", "grey29"))

ggsave("./output/corSoilSolutionFloor.jpeg", width = 16, height = 12, dpi=1200)


#correlation plot 20cm 2001-2018
library(readxl)
datacor20 <- read_excel("./correlation20.xlsx")
View(datacor20)

X<-datacor20[,4:11]
ggpairs(X) 
ggpairs(X, aes(colour = as.factor(datacor20$Type), alpha = 0.5), 
        upper = list(continuous = wrap("cor", size = 4.4, 
                                       fontface = "bold"))) + scale_color_manual(values=c("grey70", "grey29")) + scale_fill_manual(values=c("grey70", "grey29"))

ggsave("./output/corSoilSolution20cm.jpeg", width = 16, height = 12, dpi=1200)


#correlation plot 50cm 2001-2018
library(GGally)
library(readxl)
datacor50 <- read_excel("./correlation50.xlsx")
View(datacor50)

X<-datacor50[,4:11]
ggpairs(X) 
ggpairs(X, aes(colour = as.factor(datacor50$Type), alpha = 0.5), 
        upper = list(continuous = wrap("cor", size = 4.4, 
                                       fontface = "bold"))) + scale_color_manual(values=c("grey70", "grey29")) + scale_fill_manual(values=c("grey70", "grey29"))

ggsave("./output/corSoilSolution50cm.jpeg", width = 16, height = 12, dpi=1200)


#correlation plot 100cm 2001-2018
library(GGally)
library(readxl)
datacor100 <- read_excel("./correlation100.xlsx")
View(datacor100)

X<-datacor100[,4:11]
ggpairs(X) 
ggpairs(X, aes(colour = as.factor(datacor100$Type), alpha = 0.5), 
        upper = list(continuous = wrap("cor", size = 4.4, 
                                       fontface = "bold"))) + scale_color_manual(values=c("grey70", "grey29")) + scale_fill_manual(values=c("grey70", "grey29"))

ggsave("./output/corSoilSolution100cm.jpeg", width = 16, height = 12, dpi=1200)


#####################################  LMM pathway  ###################################
library(nlme)
library(lattice)
library(MuMIn)
library(multcomp)
library(effects)
library(emmeans)
library(lsmeans)
library(stargazer)
library(ggplot2)

# SpecDatLMM_SF   DM_kg  N_kg  S_kg  Ca_kg  Mg_kg  K_kg
# SpecDat_FAL  FAL_DM  FAL_N  FAL_S  FAL_Ca  FAL_Mg  FAL_K  time_DM_year  time_N_year  time_S_year  time_Ca_year  time_Mg_year  time_K_year
# SpecDat_Lit  DM_kg_ha_yr  N_kg_ha_yr  S_kg_ha_yr  Ca_kg_ha_yr  Mg_kg_ha_yr  K_kg_ha_yr 

library(readxl)
SpecDatLMM_SF <- read_excel("./SpecDatLMM_SF.xlsx", 
                            col_types = c("text", "text", "text", 
                                          "text", "text", "numeric", "numeric", 
                                          "numeric", "numeric", "numeric", 
                                          "numeric"))
View(SpecDatLMM_SF)
attach(SpecDatLMM_SF)


SpecDatLMM_FAL <- read_excel("./SpecDatLMM_FAL.xlsx", 
                             col_types = c("text", "text", "text", 
                                           "numeric", "numeric", "numeric", 
                                           "numeric", "numeric", "numeric", 
                                           "numeric", "numeric", "numeric", 
                                           "numeric", "numeric", "numeric"))
View(SpecDatLMM_FAL)
attach(SpecDatLMM_FAL)

SpecDatLMM_Lit <- read_excel("./SpecDatLMM_Lit.xlsx", 
                             col_types = c("text", "text", "text", 
                                           "text", "numeric", "numeric", "numeric", 
                                           "numeric", "numeric", "numeric"))
View(SpecDat_Lit)
attach(SpecDat_Lit)

SpecDatLMM_SF$ID <- as.factor(SpecDatLMM_SF$ID)
SpecDatLMM_FAL$ID <- as.factor(SpecDatLMM_FAL$ID)
SpecDatLMM_Lit$ID <- as.factor(SpecDatLMM_Lit$ID)

############ Floor Model ############

# create subset Floor
library(dplyr)
Floor_SpecDatLMM_SF <- SpecDatLMM_SF %>%
  filter(Layer == "Floor")

###### DM Floor ######
# DM Floor, log10
DM_Floor_modelX1 <- formula(log10(DM_kg) ~ Type, data = Floor_SpecDatLMM_SF, na.option = "na.omit")
DM_Floor_modelX11_ML <- lme(DM_Floor_modelX1, random = ~ 1|Site, method = "ML", data = Floor_SpecDatLMM_SF, na.action ="na.omit")  
summary(DM_Floor_modelX11_ML) 
plot(DM_Floor_modelX11_ML)

# variance allowed
DM_Floor_modelX13_ML <- update(DM_Floor_modelX11_ML,  na.action = "na.omit", weights = varIdent(form = ~ 1 | Site))
summary(DM_Floor_modelX13_ML)
plot(DM_Floor_modelX13_ML)
plot(DM_Floor_modelX13_ML, Site ~ resid(.), abline=0)
plot(DM_Floor_modelX13_ML, Type ~ resid(.), abline=0)
plot(DM_Floor_modelX13_ML, Layer ~ fitted(.), abline=0)
plot(DM_Floor_modelX13_ML, Site ~ fitted(.), abline=0)
r.squaredGLMM(DM_Floor_modelX13_ML)
anova(DM_Floor_modelX13_ML)
plot(allEffects(DM_Floor_modelX13_ML))

# REML estimation
DM_Floor_modelX13_REML <- update(DM_Floor_modelX13_ML, na.action = "na.omit", method="REML")
summary(DM_Floor_modelX13_REML) # export
plot(DM_Floor_modelX13_REML)
plot(DM_Floor_modelX13_REML, Site ~ resid(.), abline=0)
plot(DM_Floor_modelX13_REML, Type ~ resid(.), abline=0)
plot(DM_Floor_modelX13_REML, Site ~ fitted(.), abline=0)
plot(DM_Floor_modelX13_REML, Type ~ fitted(.), abline=0)

anova(DM_Floor_modelX13_REML) # export
r.squaredGLMM(DM_Floor_modelX13_REML) # export

# back-transformation (with packages: eemeans and effects)
plot(allEffects(DM_Floor_modelX13_REML, residuals = TRUE))

ef_DM_Floor <- effect("Type", DM_Floor_modelX13_REML)
summary(ef_DM_Floor)

margDM_Floor_REML <- lsmeans(DM_Floor_modelX13_REML, ~Type, mult.name="Type", data=Floor_SpecDatLMM_SF)
margDM_Floor_REML_bt <- regrid(margDM_Floor_REML, transform = "response") # back-transformation
cld(margDM_Floor_REML_bt,
    alpha=0.05,
    Letters=letters, adjust="fdr")

emmip(DM_Floor_modelX13_REML, ~Type, data=Floor_SpecDatLMM_SF, CIs=TRUE)+
  geom_point(aes(x = factor(Type), y = log10(DM_kg)), data = Floor_SpecDatLMM_SF, pch = 1, color = "light blue")

DM_Floor.emm <- emmeans(DM_Floor_modelX13_REML, ~ Type, data=Floor_SpecDatLMM_SF, type="response")
summary(DM_Floor.emm)
pairs(DM_Floor.emm) 
pwpp(DM_Floor.emm)

DM_Floor.emm.s <-contrast(regrid(DM_Floor.emm), transform = "response")
confint(DM_Floor.emm.s, adjust = "bonferroni")
pairs(DM_Floor.emm.s)
pwpp(DM_Floor.emm.s)

##################################################

###### N Floor ######
# N Floor, log10
N_Floor_modelX1 <- formula(log10(N_kg) ~ Type, data = Floor_SpecDatLMM_SF, na.option = "na.omit")
N_Floor_modelX11_ML <- lme(N_Floor_modelX1, random = ~ 1|Site, method = "ML", data = Floor_SpecDatLMM_SF, na.action ="na.omit")  
summary(N_Floor_modelX11_ML) 
plot(N_Floor_modelX11_ML)

# variance allowed, followed by REML estimation and log-back-transformation
N_Floor_modelX13_ML <- update(N_Floor_modelX11_ML,  na.action = "na.omit", weights = varIdent(form = ~ 1 | Site))
summary(N_Floor_modelX13_ML)
plot(N_Floor_modelX13_ML)
plot(N_Floor_modelX13_ML, Site ~ resid(.), abline=0)
plot(N_Floor_modelX13_ML, Type ~ resid(.), abline=0)
plot(N_Floor_modelX13_ML, Layer ~ fitted(.), abline=0)
plot(N_Floor_modelX13_ML, Site ~ fitted(.), abline=0)
r.squaredGLMM(N_Floor_modelX13_ML)
anova(N_Floor_modelX13_ML)
plot(allEffects(N_Floor_modelX13_ML))

N_Floor_modelX13_REML <- update(N_Floor_modelX13_ML, na.action = "na.omit", method="REML")
summary(N_Floor_modelX13_REML) # export
plot(N_Floor_modelX13_REML)
plot(N_Floor_modelX13_REML, Site ~ resid(.), abline=0)
plot(N_Floor_modelX13_REML, Type ~ resid(.), abline=0)
plot(N_Floor_modelX13_REML, Site ~ fitted(.), abline=0)
plot(N_Floor_modelX13_REML, Type ~ fitted(.), abline=0)

anova(N_Floor_modelX13_REML) # export
r.squaredGLMM(N_Floor_modelX13_REML) # export

plot(allEffects(N_Floor_modelX13_REML, residuals = TRUE))

ef_N_Floor <- effect("Type", N_Floor_modelX13_REML)
summary(ef_N_Floor)

margN_Floor_REML <- lsmeans(N_Floor_modelX13_REML, ~Type, mult.name="Type", data=Floor_SpecDatLMM_SF)
margN_Floor_REML_bt <- regrid(margN_Floor_REML, transform = "response")
cld(margN_Floor_REML_bt,
    alpha=0.05,
    Letters=letters, adjust="fdr")

emmip(N_Floor_modelX13_REML, ~Type, data=Floor_SpecDatLMM_SF, CIs=TRUE)+
  geom_point(aes(x = factor(Type), y = log10(N_kg)), data = Floor_SpecDatLMM_SF, pch = 1, color = "light blue")

N_Floor.emm <- emmeans(N_Floor_modelX13_REML, ~ Type, data=Floor_SpecDatLMM_SF, type="response")
summary(N_Floor.emm) # export
pairs(N_Floor.emm)
pwpp(N_Floor.emm)

N_Floor.emm.s <-contrast(regrid(N_Floor.emm), transform = "response")
confint(N_Floor.emm.s, adjust = "bonferroni")
pairs(N_Floor.emm.s)
pwpp(N_Floor.emm.s)


###### S Floor ######
# S Floor, log10
S_Floor_modelX1 <- formula(log10(S_kg) ~ Type, data = Floor_SpecDatLMM_SF, na.option = "na.omit")
S_Floor_modelX11_ML <- lme(S_Floor_modelX1, random = ~ 1|Site, method = "ML", data = Floor_SpecDatLMM_SF, na.action ="na.omit")  
summary(S_Floor_modelX11_ML) 
plot(S_Floor_modelX11_ML)

# variance allowed, followed by REML estimation and log-back-transformation
S_Floor_modelX13_ML <- update(S_Floor_modelX11_ML,  na.action = "na.omit", weights = varIdent(form = ~ 1 | Site))
summary(S_Floor_modelX13_ML)
plot(S_Floor_modelX13_ML)
plot(S_Floor_modelX13_ML, Site ~ resid(.), abline=0)
plot(S_Floor_modelX13_ML, Type ~ resid(.), abline=0)
plot(S_Floor_modelX13_ML, Layer ~ fitted(.), abline=0)
plot(S_Floor_modelX13_ML, Site ~ fitted(.), abline=0)
r.squaredGLMM(S_Floor_modelX13_ML)
anova(S_Floor_modelX13_ML)
plot(allEffects(S_Floor_modelX13_ML))

S_Floor_modelX13_REML <- update(S_Floor_modelX13_ML, na.action = "na.omit", method="REML")
summary(S_Floor_modelX13_REML)
plot(S_Floor_modelX13_REML)
plot(S_Floor_modelX13_REML, Site ~ resid(.), abline=0)
plot(S_Floor_modelX13_REML, Type ~ resid(.), abline=0)
plot(S_Floor_modelX13_REML, Site ~ fitted(.), abline=0)
plot(S_Floor_modelX13_REML, Type ~ fitted(.), abline=0)

anova(S_Floor_modelX13_REML)
r.squaredGLMM(S_Floor_modelX13_REML)

plot(allEffects(S_Floor_modelX13_REML, residuals = TRUE))

ef_S_Floor <- effect("Type", S_Floor_modelX13_REML)
summary(ef_S_Floor)

margS_Floor_REML <- lsmeans(S_Floor_modelX13_REML, ~Type, mult.name="Type", data=Floor_SpecDatLMM_SF)
margS_Floor_REML_bt <- regrid(margS_Floor_REML, transform = "response")
cld(margS_Floor_REML_bt,
    alpha=0.05,
    Letters=letters, adjust="fdr")

emmip(S_Floor_modelX13_REML, ~Type, data=Floor_SpecDatLMM_SF, CIs=TRUE)+
  geom_point(aes(x = factor(Type), y = log10(S_kg)), data = Floor_SpecDatLMM_SF, pch = 1, color = "light blue")

S_Floor.emm <- emmeans(S_Floor_modelX13_REML, ~ Type, data=Floor_SpecDatLMM_SF, type="response")
summary(S_Floor.emm)
pairs(S_Floor.emm)
pwpp(S_Floor.emm)

S_Floor.emm.s <-contrast(regrid(S_Floor.emm), transform = "response")
confint(S_Floor.emm.s, adjust = "bonferroni")
pairs(S_Floor.emm.s)
pwpp(S_Floor.emm.s)


###### Ca Floor ######
# Ca Floor, log10
Ca_Floor_modelX1 <- formula(log10(Ca_kg) ~ Type, data = Floor_SpecDatLMM_SF, na.option = "na.omit")
Ca_Floor_modelX11_ML <- lme(Ca_Floor_modelX1, random = ~ 1|Site, method = "ML", data = Floor_SpecDatLMM_SF, na.action ="na.omit")  
summary(Ca_Floor_modelX11_ML) 
plot(Ca_Floor_modelX11_ML) #show patterns

# variance allowed, followed by REML estimation and log-back-transformation
Ca_Floor_modelX13_ML <- update(Ca_Floor_modelX11_ML,  na.action = "na.omit", weights = varIdent(form = ~ 1 | Site))
summary(Ca_Floor_modelX13_ML)
plot(Ca_Floor_modelX13_ML)
plot(Ca_Floor_modelX13_ML, Site ~ resid(.), abline=0)
plot(Ca_Floor_modelX13_ML, Type ~ resid(.), abline=0)
plot(Ca_Floor_modelX13_ML, Layer ~ fitted(.), abline=0)
plot(Ca_Floor_modelX13_ML, Site ~ fitted(.), abline=0)
r.squaredGLMM(Ca_Floor_modelX13_ML)
anova(Ca_Floor_modelX13_ML)
plot(allEffects(Ca_Floor_modelX13_ML))

Ca_Floor_modelX13_REML <- update(Ca_Floor_modelX13_ML, na.action = "na.omit", method="REML")
summary(Ca_Floor_modelX13_REML)
plot(Ca_Floor_modelX13_REML)
plot(Ca_Floor_modelX13_REML, Site ~ resid(.), abline=0)
plot(Ca_Floor_modelX13_REML, Type ~ resid(.), abline=0)
plot(Ca_Floor_modelX13_REML, Site ~ fitted(.), abline=0)
plot(Ca_Floor_modelX13_REML, Type ~ fitted(.), abline=0)

anova(Ca_Floor_modelX13_REML)
r.squaredGLMM(Ca_Floor_modelX13_REML)

plot(allEffects(Ca_Floor_modelX13_REML, residuals = TRUE))

ef_Ca_Floor <- effect("Type", Ca_Floor_modelX13_REML)
summary(ef_Ca_Floor)

margCa_Floor_REML <- lsmeans(Ca_Floor_modelX13_REML, ~Type, mult.name="Type", data=Floor_SpecDatLMM_SF)
margCa_Floor_REML_bt <- regrid(margCa_Floor_REML, transform = "response")
cld(margCa_Floor_REML_bt,
    alpha=0.05,
    Letters=letters, adjust="fdr")

emmip(Ca_Floor_modelX13_REML, ~Type, data=Floor_SpecDatLMM_SF, CIs=TRUE)+
  geom_point(aes(x = factor(Type), y = log10(Ca_kg)), data = Floor_SpecDatLMM_SF, pch = 1, color = "light blue")

Ca_Floor.emm <- emmeans(Ca_Floor_modelX13_REML, ~ Type, data=Floor_SpecDatLMM_SF, type="response")
summary(Ca_Floor.emm)
pairs(Ca_Floor.emm)
pwpp(Ca_Floor.emm)

Ca_Floor.emm.s <-contrast(regrid(Ca_Floor.emm), transform = "response")
confint(Ca_Floor.emm.s, adjust = "bonferroni")
pairs(Ca_Floor.emm.s)
pwpp(Ca_Floor.emm.s)


###### Mg Floor ######
# Mg Floor, log10
Mg_Floor_modelX1 <- formula(log10(Mg_kg) ~ Type, data = Floor_SpecDatLMM_SF, na.option = "na.omit")
Mg_Floor_modelX11_ML <- lme(Mg_Floor_modelX1, random = ~ 1|Site, method = "ML", data = Floor_SpecDatLMM_SF, na.action ="na.omit")  
summary(Mg_Floor_modelX11_ML) 
plot(Mg_Floor_modelX11_ML)

# variance allowed, followed by REML estimation and log-back-transformation
Mg_Floor_modelX13_ML <- update(Mg_Floor_modelX11_ML,  na.action = "na.omit", weights = varIdent(form = ~ 1 | Site))
summary(Mg_Floor_modelX13_ML)
plot(Mg_Floor_modelX13_ML)
plot(Mg_Floor_modelX13_ML, Site ~ resid(.), abline=0)
plot(Mg_Floor_modelX13_ML, Type ~ resid(.), abline=0)
plot(Mg_Floor_modelX13_ML, Layer ~ fitted(.), abline=0)
plot(Mg_Floor_modelX13_ML, Site ~ fitted(.), abline=0)
r.squaredGLMM(Mg_Floor_modelX13_ML)
anova(Mg_Floor_modelX13_ML)
plot(allEffects(Mg_Floor_modelX13_ML))

Mg_Floor_modelX13_REML <- update(Mg_Floor_modelX13_ML, na.action = "na.omit", method="REML")
summary(Mg_Floor_modelX13_REML)
plot(Mg_Floor_modelX13_REML)
plot(Mg_Floor_modelX13_REML, Site ~ resid(.), abline=0)
plot(Mg_Floor_modelX13_REML, Type ~ resid(.), abline=0)
plot(Mg_Floor_modelX13_REML, Site ~ fitted(.), abline=0)
plot(Mg_Floor_modelX13_REML, Type ~ fitted(.), abline=0)

anova(Mg_Floor_modelX13_REML)
r.squaredGLMM(Mg_Floor_modelX13_REML)

plot(allEffects(Mg_Floor_modelX13_REML, residuals = TRUE))

ef_Mg_Floor <- effect("Type", Mg_Floor_modelX13_REML)
summary(ef_Mg_Floor)

margMg_Floor_REML <- lsmeans(Mg_Floor_modelX13_REML, ~Type, mult.name="Type", data=Floor_SpecDatLMM_SF)
margMg_Floor_REML_bt <- regrid(margMg_Floor_REML, transform = "response")
cld(margMg_Floor_REML_bt,
    alpha=0.05,
    Letters=letters, adjust="fdr")

emmip(Mg_Floor_modelX13_REML, ~Type, data=Floor_SpecDatLMM_SF, CIs=TRUE)+
  geom_point(aes(x = factor(Type), y = log10(Mg_kg)), data = Floor_SpecDatLMM_SF, pch = 1, color = "light blue")

Mg_Floor.emm <- emmeans(Mg_Floor_modelX13_REML, ~ Type, data=Floor_SpecDatLMM_SF, type="response")
summary(Mg_Floor.emm)
pairs(Mg_Floor.emm)
pwpp(Mg_Floor.emm)

Mg_Floor.emm.s <-contrast(regrid(Mg_Floor.emm), transform = "response")
confint(Mg_Floor.emm.s, adjust = "bonferroni")
pairs(Mg_Floor.emm.s)
pwpp(Mg_Floor.emm.s)


###### K Floor ######
# K Floor, log10
K_Floor_modelX1 <- formula(log10(K_kg) ~ Type, data = Floor_SpecDatLMM_SF, na.option = "na.omit")
K_Floor_modelX11_ML <- lme(K_Floor_modelX1, random = ~ 1|Site, method = "ML", data = Floor_SpecDatLMM_SF, na.action ="na.omit")  
summary(K_Floor_modelX11_ML) 
plot(K_Floor_modelX11_ML)

# variance allowed, followed by REML estimation and log-back-transformation
K_Floor_modelX13_ML <- update(K_Floor_modelX11_ML,  na.action = "na.omit", weights = varIdent(form = ~ 1 | Site))
summary(K_Floor_modelX13_ML)
plot(K_Floor_modelX13_ML)
plot(K_Floor_modelX13_ML, Site ~ resid(.), abline=0)
plot(K_Floor_modelX13_ML, Type ~ resid(.), abline=0)
plot(K_Floor_modelX13_ML, Layer ~ fitted(.), abline=0)
plot(K_Floor_modelX13_ML, Site ~ fitted(.), abline=0)
r.squaredGLMM(K_Floor_modelX13_ML)
anova(K_Floor_modelX13_ML)
plot(allEffects(K_Floor_modelX13_ML))

K_Floor_modelX13_REML <- update(K_Floor_modelX13_ML, na.action = "na.omit", method="REML")
summary(K_Floor_modelX13_REML)
plot(K_Floor_modelX13_REML)
plot(K_Floor_modelX13_REML, Site ~ resid(.), abline=0)
plot(K_Floor_modelX13_REML, Type ~ resid(.), abline=0)
plot(K_Floor_modelX13_REML, Site ~ fitted(.), abline=0)
plot(K_Floor_modelX13_REML, Type ~ fitted(.), abline=0)

anova(K_Floor_modelX13_REML)
r.squaredGLMM(K_Floor_modelX13_REML)

plot(allEffects(K_Floor_modelX13_REML, residuals = TRUE))

ef_K_Floor <- effect("Type", K_Floor_modelX13_REML)
summary(ef_K_Floor)

margK_Floor_REML <- lsmeans(K_Floor_modelX13_REML, ~Type, mult.name="Type", data=Floor_SpecDatLMM_SF)
margK_Floor_REML_bt <- regrid(margK_Floor_REML, transform = "response")
cld(margK_Floor_REML_bt,
    alpha=0.05,
    Letters=letters, adjust="fdr")

emmip(K_Floor_modelX13_REML, ~Type, data=Floor_SpecDatLMM_SF, CIs=TRUE)+
  geom_point(aes(x = factor(Type), y = log10(K_kg)), data = Floor_SpecDatLMM_SF, pch = 1, color = "light blue")

K_Floor.emm <- emmeans(K_Floor_modelX13_REML, ~ Type, data=Floor_SpecDatLMM_SF, type="response")
summary(K_Floor.emm)
pairs(K_Floor.emm)
pwpp(K_Floor.emm)

K_Floor.emm.s <-contrast(regrid(K_Floor.emm), transform = "response")
confint(K_Floor.emm.s, adjust = "bonferroni")
pairs(K_Floor.emm.s)
pwpp(K_Floor.emm.s)


############ Mineral Soil Model ############

# create subset Mineral Soil
library(dplyr)
Soil_SpecDatLMM_SF <- SpecDatLMM_SF %>%
  filter(Layer == "Soil")

###### N Mineral Soil ######
# N Soil, log10
N_Soil_modelX1 <- formula(log10(N_kg) ~ Type, data = Soil_SpecDatLMM_SF, na.option = "na.omit")
N_Soil_modelX11_ML <- lme(N_Soil_modelX1, random = ~ 1|Site, method = "ML", data = Soil_SpecDatLMM_SF, na.action ="na.omit")  
summary(N_Soil_modelX11_ML) 
plot(N_Soil_modelX11_ML)

# variance allowed, followed by REML estimation
N_Soil_modelX13_ML <- update(N_Soil_modelX11_ML,  na.action = "na.omit", weights = varIdent(form = ~ 1 | Site))
summary(N_Soil_modelX13_ML)
plot(N_Soil_modelX13_ML)
plot(N_Soil_modelX13_ML, Site ~ resid(.), abline=0)
plot(N_Soil_modelX13_ML, Type ~ resid(.), abline=0)
plot(N_Soil_modelX13_ML, Layer ~ fitted(.), abline=0)
plot(N_Soil_modelX13_ML, Site ~ fitted(.), abline=0)
r.squaredGLMM(N_Soil_modelX13_ML)
anova(N_Soil_modelX13_ML)
plot(allEffects(N_Soil_modelX13_ML))

N_Soil_modelX13_REML <- update(N_Soil_modelX13_ML, na.action = "na.omit", method="REML")
summary(N_Soil_modelX13_REML)
plot(N_Soil_modelX13_REML)
plot(N_Soil_modelX13_REML, Site ~ resid(.), abline=0)
plot(N_Soil_modelX13_REML, Type ~ resid(.), abline=0)
plot(N_Soil_modelX13_REML, Site ~ fitted(.), abline=0)
plot(N_Soil_modelX13_REML, Type ~ fitted(.), abline=0)

anova(N_Soil_modelX13_REML)
r.squaredGLMM(N_Soil_modelX13_REML)

plot(allEffects(N_Soil_modelX13_REML, residuals = TRUE))

ef_N_Soil <- effect("Type", N_Soil_modelX13_REML)
summary(ef_N_Soil)

margN_Soil_REML <- lsmeans(N_Soil_modelX13_REML, ~Type, mult.name="Type", data=Soil_SpecDatLMM_SF)
margN_Soil_REML_bt <- regrid(margN_Soil_REML, transform = "response")
cld(margN_Soil_REML_bt,
    alpha=0.05,
    Letters=letters, adjust="fdr")

emmip(N_Soil_modelX13_REML, ~Type, data=Soil_SpecDatLMM_SF, CIs=TRUE)+
  geom_point(aes(x = factor(Type), y = log10(N_kg)), data = Soil_SpecDatLMM_SF, pch = 1, color = "light blue")

N_Soil.emm <- emmeans(N_Soil_modelX13_REML, ~ Type, data=Soil_SpecDatLMM_SF, type="response")
summary(N_Soil.emm)
pairs(N_Soil.emm)
pwpp(N_Soil.emm)

N_Soil.emm.s <-contrast(regrid(N_Soil.emm), transform = "response")
confint(N_Soil.emm.s, adjust = "bonferroni")
pairs(N_Soil.emm.s)
pwpp(N_Soil.emm.s)


###### S Mineral Soil ######
# S Soil, log10
S_Soil_modelX1 <- formula(log10(S_kg) ~ Type, data = Soil_SpecDatLMM_SF, na.option = "na.omit")
S_Soil_modelX11_ML <- lme(S_Soil_modelX1, random = ~ 1|Site, method = "ML", data = Soil_SpecDatLMM_SF, na.action ="na.omit")  
summary(S_Soil_modelX11_ML) 
plot(S_Soil_modelX11_ML)

# variance allowed, followed by REML estimation
S_Soil_modelX13_ML <- update(S_Soil_modelX11_ML,  na.action = "na.omit", weights = varIdent(form = ~ 1 | Site))
summary(S_Soil_modelX13_ML)
plot(S_Soil_modelX13_ML)
plot(S_Soil_modelX13_ML, Site ~ resid(.), abline=0)
plot(S_Soil_modelX13_ML, Type ~ resid(.), abline=0)
plot(S_Soil_modelX13_ML, Layer ~ fitted(.), abline=0)
plot(S_Soil_modelX13_ML, Site ~ fitted(.), abline=0)
r.squaredGLMM(S_Soil_modelX13_ML)
anova(S_Soil_modelX13_ML)
plot(allEffects(S_Soil_modelX13_ML))

S_Soil_modelX13_REML <- update(S_Soil_modelX13_ML, na.action = "na.omit", method="REML")
summary(S_Soil_modelX13_REML)
plot(S_Soil_modelX13_REML)
plot(S_Soil_modelX13_REML, Site ~ resid(.), abline=0)
plot(S_Soil_modelX13_REML, Type ~ resid(.), abline=0)
plot(S_Soil_modelX13_REML, Site ~ fitted(.), abline=0)
plot(S_Soil_modelX13_REML, Type ~ fitted(.), abline=0)

anova(S_Soil_modelX13_REML)
r.squaredGLMM(S_Soil_modelX13_REML)

plot(allEffects(S_Soil_modelX13_REML, residuals = TRUE))

ef_S_Soil <- effect("Type", S_Soil_modelX13_REML)
summary(ef_S_Soil)

margS_Soil_REML <- lsmeans(S_Soil_modelX13_REML, ~Type, mult.name="Type", data=Soil_SpecDatLMM_SF)
margS_Soil_REML_bt <- regrid(margS_Soil_REML, transform = "response")
cld(margS_Soil_REML_bt,
    alpha=0.05,
    Letters=letters, adjust="fdr")

emmip(S_Soil_modelX13_REML, ~Type, data=Soil_SpecDatLMM_SF, CIs=TRUE)+
  geom_point(aes(x = factor(Type), y = log10(S_kg)), data = Soil_SpecDatLMM_SF, pch = 1, color = "light blue")

S_Soil.emm <- emmeans(S_Soil_modelX13_REML, ~ Type, data=Soil_SpecDatLMM_SF, type="response")
summary(S_Soil.emm)
pairs(S_Soil.emm)
pwpp(S_Soil.emm)

S_Soil.emm.s <-contrast(regrid(S_Soil.emm), transform = "response")
confint(S_Soil.emm.s, adjust = "bonferroni")
pairs(S_Soil.emm.s)
pwpp(S_Soil.emm.s)


###### Ca Mineral Soil ######
# Ca Soil, log10
Ca_Soil_modelX1 <- formula(log10(Ca_kg) ~ Type, data = Soil_SpecDatLMM_SF, na.option = "na.omit")
Ca_Soil_modelX11_ML <- lme(Ca_Soil_modelX1, random = ~ 1|Site, method = "ML", data = Soil_SpecDatLMM_SF, na.action ="na.omit")  
summary(Ca_Soil_modelX11_ML) 
plot(Ca_Soil_modelX11_ML)

# variance allowed, followed by REML estimation
Ca_Soil_modelX13_ML <- update(Ca_Soil_modelX11_ML,  na.action = "na.omit", weights = varIdent(form = ~ 1 | Site))
summary(Ca_Soil_modelX13_ML)
plot(Ca_Soil_modelX13_ML)
plot(Ca_Soil_modelX13_ML, Site ~ resid(.), abline=0)
plot(Ca_Soil_modelX13_ML, Type ~ resid(.), abline=0)
plot(Ca_Soil_modelX13_ML, Layer ~ fitted(.), abline=0)
plot(Ca_Soil_modelX13_ML, Site ~ fitted(.), abline=0)
r.squaredGLMM(Ca_Soil_modelX13_ML)
anova(Ca_Soil_modelX13_ML)
plot(allEffects(Ca_Soil_modelX13_ML))

Ca_Soil_modelX13_REML <- update(Ca_Soil_modelX13_ML, na.action = "na.omit", method="REML")
summary(Ca_Soil_modelX13_REML)
plot(Ca_Soil_modelX13_REML)
plot(Ca_Soil_modelX13_REML, Site ~ resid(.), abline=0)
plot(Ca_Soil_modelX13_REML, Type ~ resid(.), abline=0)
plot(Ca_Soil_modelX13_REML, Site ~ fitted(.), abline=0)
plot(Ca_Soil_modelX13_REML, Type ~ fitted(.), abline=0)

anova(Ca_Soil_modelX13_REML)
r.squaredGLMM(Ca_Soil_modelX13_REML)

plot(allEffects(Ca_Soil_modelX13_REML, residuals = TRUE))

ef_Ca_Soil <- effect("Type", Ca_Soil_modelX13_REML)
summary(ef_Ca_Soil)

margCa_Soil_REML <- lsmeans(Ca_Soil_modelX13_REML, ~Type, mult.name="Type", data=Soil_SpecDatLMM_SF)
margCa_Soil_REML_bt <- regrid(margCa_Soil_REML, transform = "response")
cld(margCa_Soil_REML_bt,
    alpha=0.05,
    Letters=letters, adjust="fdr")

emmip(Ca_Soil_modelX13_REML, ~Type, data=Soil_SpecDatLMM_SF, CIs=TRUE)+
  geom_point(aes(x = factor(Type), y = log10(Ca_kg)), data = Soil_SpecDatLMM_SF, pch = 1, color = "light blue")

Ca_Soil.emm <- emmeans(Ca_Soil_modelX13_REML, ~ Type, data=Soil_SpecDatLMM_SF, type="response")
summary(Ca_Soil.emm)
pairs(Ca_Soil.emm)
pwpp(Ca_Soil.emm)

Ca_Soil.emm.s <-contrast(regrid(Ca_Soil.emm), transform = "response")
confint(Ca_Soil.emm.s, adjust = "bonferroni")
pairs(Ca_Soil.emm.s)
pwpp(Ca_Soil.emm.s)


###### Mg Mineral Soil ######
# Mg Soil, log10
Mg_Soil_modelX1 <- formula(log10(Mg_kg) ~ Type, data = Soil_SpecDatLMM_SF, na.option = "na.omit")
Mg_Soil_modelX11_ML <- lme(Mg_Soil_modelX1, random = ~ 1|Site, method = "ML", data = Soil_SpecDatLMM_SF, na.action ="na.omit")  
summary(Mg_Soil_modelX11_ML) 
plot(Mg_Soil_modelX11_ML)

# variance allowed, followed by REML estimation
Mg_Soil_modelX13_ML <- update(Mg_Soil_modelX11_ML,  na.action = "na.omit", weights = varIdent(form = ~ 1 | Site))
summary(Mg_Soil_modelX13_ML)
plot(Mg_Soil_modelX13_ML)
plot(Mg_Soil_modelX13_ML, Site ~ resid(.), abline=0)
plot(Mg_Soil_modelX13_ML, Type ~ resid(.), abline=0)
plot(Mg_Soil_modelX13_ML, Layer ~ fitted(.), abline=0)
plot(Mg_Soil_modelX13_ML, Site ~ fitted(.), abline=0)
r.squaredGLMM(Mg_Soil_modelX13_ML)
anova(Mg_Soil_modelX13_ML)
plot(allEffects(Mg_Soil_modelX13_ML))

Mg_Soil_modelX13_REML <- update(Mg_Soil_modelX13_ML, na.action = "na.omit", method="REML")
summary(Mg_Soil_modelX13_REML)
plot(Mg_Soil_modelX13_REML)
plot(Mg_Soil_modelX13_REML, Site ~ resid(.), abline=0)
plot(Mg_Soil_modelX13_REML, Type ~ resid(.), abline=0)
plot(Mg_Soil_modelX13_REML, Site ~ fitted(.), abline=0)
plot(Mg_Soil_modelX13_REML, Type ~ fitted(.), abline=0)

anova(Mg_Soil_modelX13_REML)
r.squaredGLMM(Mg_Soil_modelX13_REML)

plot(allEffects(Mg_Soil_modelX13_REML, residuals = TRUE))

ef_Mg_Soil <- effect("Type", Mg_Soil_modelX13_REML)
summary(ef_Mg_Soil)

margMg_Soil_REML <- lsmeans(Mg_Soil_modelX13_REML, ~Type, mult.name="Type", data=Soil_SpecDatLMM_SF)
margMg_Soil_REML_bt <- regrid(margMg_Soil_REML, transform = "response")
cld(margMg_Soil_REML_bt,
    alpha=0.05,
    Letters=letters, adjust="fdr")

emmip(Mg_Soil_modelX13_REML, ~Type, data=Soil_SpecDatLMM_SF, CIs=TRUE)+
  geom_point(aes(x = factor(Type), y = log10(Mg_kg)), data = Soil_SpecDatLMM_SF, pch = 1, color = "light blue")

Mg_Soil.emm <- emmeans(Mg_Soil_modelX13_REML, ~ Type, data=Soil_SpecDatLMM_SF, type="response")
summary(Mg_Soil.emm)
pairs(Mg_Soil.emm)
pwpp(Mg_Soil.emm)

Mg_Soil.emm.s <-contrast(regrid(Mg_Soil.emm), transform = "response")
confint(Mg_Soil.emm.s, adjust = "bonferroni")
pairs(Mg_Soil.emm.s)
pwpp(Mg_Soil.emm.s)


###### K Mineral Soil ######
# K Soil, log10
K_Soil_modelX1 <- formula(log10(K_kg) ~ Type, data = Soil_SpecDatLMM_SF, na.option = "na.omit")
K_Soil_modelX11_ML <- lme(K_Soil_modelX1, random = ~ 1|Site, method = "ML", data = Soil_SpecDatLMM_SF, na.action ="na.omit")  
summary(K_Soil_modelX11_ML) 
plot(K_Soil_modelX11_ML)

# variance allowed, followed by REML estimation
K_Soil_modelX13_ML <- update(K_Soil_modelX11_ML,  na.action = "na.omit", weights = varIdent(form = ~ 1 | Site))
summary(K_Soil_modelX13_ML)
plot(K_Soil_modelX13_ML)
plot(K_Soil_modelX13_ML, Site ~ resid(.), abline=0)
plot(K_Soil_modelX13_ML, Type ~ resid(.), abline=0)
plot(K_Soil_modelX13_ML, Layer ~ fitted(.), abline=0)
plot(K_Soil_modelX13_ML, Site ~ fitted(.), abline=0)
r.squaredGLMM(K_Soil_modelX13_ML)
anova(K_Soil_modelX13_ML)
plot(allEffects(K_Soil_modelX13_ML))

K_Soil_modelX13_REML <- update(K_Soil_modelX13_ML, na.action = "na.omit", method="REML")
summary(K_Soil_modelX13_REML)
plot(K_Soil_modelX13_REML)
plot(K_Soil_modelX13_REML, Site ~ resid(.), abline=0)
plot(K_Soil_modelX13_REML, Type ~ resid(.), abline=0)
plot(K_Soil_modelX13_REML, Site ~ fitted(.), abline=0)
plot(K_Soil_modelX13_REML, Type ~ fitted(.), abline=0)

anova(K_Soil_modelX13_REML)
r.squaredGLMM(K_Soil_modelX13_REML)

plot(allEffects(K_Soil_modelX13_REML, residuals = TRUE))

ef_K_Soil <- effect("Type", K_Soil_modelX13_REML)
summary(ef_K_Soil)

margK_Soil_REML <- lsmeans(K_Soil_modelX13_REML, ~Type, mult.name="Type", data=Soil_SpecDatLMM_SF)
margK_Soil_REML_bt <- regrid(margK_Soil_REML, transform = "response")
cld(margK_Soil_REML_bt,
    alpha=0.05,
    Letters=letters, adjust="fdr")

emmip(K_Soil_modelX13_REML, ~Type, data=Soil_SpecDatLMM_SF, CIs=TRUE)+
  geom_point(aes(x = factor(Type), y = log10(K_kg)), data = Soil_SpecDatLMM_SF, pch = 1, color = "light blue")

K_Soil.emm <- emmeans(K_Soil_modelX13_REML, ~ Type, data=Soil_SpecDatLMM_SF, type="response")
summary(K_Soil.emm)
pairs(K_Soil.emm)
pwpp(K_Soil.emm)

K_Soil.emm.s <-contrast(regrid(K_Soil.emm), transform = "response")
confint(K_Soil.emm.s, adjust = "bonferroni")
pairs(K_Soil.emm.s)
pwpp(K_Soil.emm.s)


############ FAL and Res_Time Model ############

###### FAL DM ######
# FAL DM, log10
DM_FAL_modelX1 <- formula(log10(FAL_DM) ~ Type, data = SpecDatLMM_FAL, na.option = "na.omit")
DM_FAL_modelX11_ML <- lme(DM_FAL_modelX1, random = ~ 1|Site/ID, method = "ML", data = SpecDatLMM_FAL, na.action ="na.omit")
summary(DM_FAL_modelX11_ML) 
plot(DM_FAL_modelX11_ML)

# variance allowed
#DM_FAL_modelX13_ML <- update(DM_FAL_modelX11_ML,  na.action = "na.omit", weights = varIdent(form = ~ 1 | Site))

# skip varIdent, followed by REML estimation
DM_FAL_modelX13_ML <- update(DM_FAL_modelX11_ML,  na.action = "na.omit")
summary(DM_FAL_modelX13_ML)
plot(DM_FAL_modelX13_ML)
plot(DM_FAL_modelX13_ML, Site ~ resid(.), abline=0)
plot(DM_FAL_modelX13_ML, Type ~ resid(.), abline=0)
plot(DM_FAL_modelX13_ML, Site ~ fitted(.), abline=0)
r.squaredGLMM(DM_FAL_modelX13_ML)
anova(DM_FAL_modelX13_ML)
plot(allEffects(DM_FAL_modelX13_ML))

DM_FAL_modelX13_REML <- update(DM_FAL_modelX13_ML, na.action = "na.omit", method="REML")
summary(DM_FAL_modelX13_REML)
plot(DM_FAL_modelX13_REML)
plot(DM_FAL_modelX13_REML, Site ~ resid(.), abline=0)
plot(DM_FAL_modelX13_REML, Type ~ resid(.), abline=0)
plot(DM_FAL_modelX13_REML, Site ~ fitted(.), abline=0)
plot(DM_FAL_modelX13_REML, Type ~ fitted(.), abline=0)

anova(DM_FAL_modelX13_REML)
r.squaredGLMM(DM_FAL_modelX13_REML)

plot(allEffects(DM_FAL_modelX13_REML, residuals = TRUE))

ef_DM_FAL <- effect("Type", DM_FAL_modelX13_REML)
summary(ef_DM_FAL)

margDM_FAL_REML <- lsmeans(DM_FAL_modelX13_REML, ~Type, mult.name="Type", data=SpecDatLMM_FAL)
margDM_FAL_REML_bt <- regrid(margDM_FAL_REML, transform = "response")
cld(margDM_FAL_REML_bt,
    alpha=0.05,
    Letters=letters, adjust="fdr")

emmip(DM_FAL_modelX13_REML, ~Type, data=SpecDatLMM_FAL, CIs=TRUE)+
  geom_point(aes(x = factor(Type), y = log10(FAL_DM)), data = SpecDatLMM_FAL, pch = 1, color = "light blue")

DM_FAL.emm <- emmeans(DM_FAL_modelX13_REML, ~ Type, data=SpecDatLMM_FAL, type="response")
summary(DM_FAL.emm)
pairs(DM_FAL.emm)
pwpp(DM_FAL.emm)

DM_FAL.emm.s <-contrast(regrid(DM_FAL.emm), transform = "response")
confint(DM_FAL.emm.s, adjust = "bonferroni")
pairs(DM_FAL.emm.s)
pwpp(DM_FAL.emm.s)

###### FAL N ######
# FAL N, log10
N_FAL_modelX1 <- formula(log10(FAL_N) ~ Type, data = SpecDatLMM_FAL, na.option = "na.omit")
N_FAL_modelX11_ML <- lme(N_FAL_modelX1, random = ~ 1|Site/ID, method = "ML", data = SpecDatLMM_FAL, na.action ="na.omit")
summary(N_FAL_modelX11_ML) 
plot(N_FAL_modelX11_ML)

# variance allowed
# N_FAL_modelX13_ML <- update(N_FAL_modelX11_ML,  na.action = "na.omit", weights = varIdent(form = ~ 1 | Site))

# skip varIdent, followed by REML estimation
N_FAL_modelX13_ML <- update(N_FAL_modelX11_ML,  na.action = "na.omit")
summary(N_FAL_modelX13_ML)
plot(N_FAL_modelX13_ML)
plot(N_FAL_modelX13_ML, Site ~ resid(.), abline=0)
plot(N_FAL_modelX13_ML, Type ~ resid(.), abline=0)
plot(N_FAL_modelX13_ML, Site ~ fitted(.), abline=0)
r.squaredGLMM(N_FAL_modelX13_ML)
anova(N_FAL_modelX13_ML)
plot(allEffects(N_FAL_modelX13_ML))

N_FAL_modelX13_REML <- update(N_FAL_modelX13_ML, na.action = "na.omit", method="REML")
summary(N_FAL_modelX13_REML)
plot(N_FAL_modelX13_REML)
plot(N_FAL_modelX13_REML, Site ~ resid(.), abline=0)
plot(N_FAL_modelX13_REML, Type ~ resid(.), abline=0)
plot(N_FAL_modelX13_REML, Site ~ fitted(.), abline=0)
plot(N_FAL_modelX13_REML, Type ~ fitted(.), abline=0)

anova(N_FAL_modelX13_REML)
r.squaredGLMM(N_FAL_modelX13_REML)

plot(allEffects(N_FAL_modelX13_REML, residuals = TRUE))

ef_N_FAL <- effect("Type", N_FAL_modelX13_REML)
summary(ef_N_FAL)

margN_FAL_REML <- lsmeans(N_FAL_modelX13_REML, ~Type, mult.name="Type", data=SpecDatLMM_FAL)
margN_FAL_REML_bt <- regrid(margN_FAL_REML, transform = "response")
cld(margN_FAL_REML_bt,
    alpha=0.05,
    Letters=letters, adjust="fdr")

emmip(N_FAL_modelX13_REML, ~Type, data=SpecDatLMM_FAL, CIs=TRUE)+
  geom_point(aes(x = factor(Type), y = log10(FAL_N)), data = SpecDatLMM_FAL, pch = 1, color = "light blue")

N_FAL.emm <- emmeans(N_FAL_modelX13_REML, ~ Type, data=SpecDatLMM_FAL, type="response")
summary(N_FAL.emm)
pairs(N_FAL.emm)
pwpp(N_FAL.emm)

N_FAL.emm.s <-contrast(regrid(N_FAL.emm), transform = "response")
confint(N_FAL.emm.s, adjust = "bonferroni")
pairs(N_FAL.emm.s)
pwpp(N_FAL.emm.s)


###### FAL S ######
# FAL S, log10
S_FAL_modelX1 <- formula(log10(FAL_S) ~ Type, data = SpecDatLMM_FAL, na.option = "na.omit")
S_FAL_modelX11_ML <- lme(S_FAL_modelX1, random = ~ 1|Site/ID, method = "ML", data = SpecDatLMM_FAL, na.action ="na.omit")
summary(S_FAL_modelX11_ML) 
plot(S_FAL_modelX11_ML)

# skip varIdent, followed by REML estimation
S_FAL_modelX13_ML <- update(S_FAL_modelX11_ML,  na.action = "na.omit")
summary(S_FAL_modelX13_ML)
plot(S_FAL_modelX13_ML)
plot(S_FAL_modelX13_ML, Site ~ resid(.), abline=0)
plot(S_FAL_modelX13_ML, Type ~ resid(.), abline=0)
plot(S_FAL_modelX13_ML, Site ~ fitted(.), abline=0)
r.squaredGLMM(S_FAL_modelX13_ML)
anova(S_FAL_modelX13_ML)
plot(allEffects(S_FAL_modelX13_ML))

S_FAL_modelX13_REML <- update(S_FAL_modelX13_ML, na.action = "na.omit", method="REML")
summary(S_FAL_modelX13_REML)
plot(S_FAL_modelX13_REML)
plot(S_FAL_modelX13_REML, Site ~ resid(.), abline=0)
plot(S_FAL_modelX13_REML, Type ~ resid(.), abline=0)
plot(S_FAL_modelX13_REML, Site ~ fitted(.), abline=0)
plot(S_FAL_modelX13_REML, Type ~ fitted(.), abline=0)

anova(S_FAL_modelX13_REML)
r.squaredGLMM(S_FAL_modelX13_REML)

plot(allEffects(S_FAL_modelX13_REML, residuals = TRUE))

ef_S_FAL <- effect("Type", S_FAL_modelX13_REML)
summary(ef_S_FAL)

margS_FAL_REML <- lsmeans(S_FAL_modelX13_REML, ~Type, mult.name="Type", data=SpecDatLMM_FAL)
margS_FAL_REML_bt <- regrid(margS_FAL_REML, transform = "response")
cld(margS_FAL_REML_bt,
    alpha=0.05,
    Letters=letters, adjust="fdr")

emmip(S_FAL_modelX13_REML, ~Type, data=SpecDatLMM_FAL, CIs=TRUE)+
  geom_point(aes(x = factor(Type), y = log10(FAL_S)), data = SpecDatLMM_FAL, pch = 1, color = "light blue")

S_FAL.emm <- emmeans(S_FAL_modelX13_REML, ~ Type, data=SpecDatLMM_FAL, type="response")
summary(S_FAL.emm)
pairs(S_FAL.emm)
pwpp(S_FAL.emm)

S_FAL.emm.s <-contrast(regrid(S_FAL.emm), transform = "response")
confint(S_FAL.emm.s, adjust = "bonferroni")
pairs(S_FAL.emm.s)
pwpp(S_FAL.emm.s)


###### FAL Ca ######
# FAL Ca, log10
Ca_FAL_modelX1 <- formula(log10(FAL_Ca) ~ Type, data = SpecDatLMM_FAL, na.option = "na.omit")
Ca_FAL_modelX11_ML <- lme(Ca_FAL_modelX1, random = ~ 1|Site/ID, method = "ML", data = SpecDatLMM_FAL, na.action ="na.omit")
summary(Ca_FAL_modelX11_ML) 
plot(Ca_FAL_modelX11_ML)

# variance allowed
# Ca_FAL_modelX13_ML <- update(Ca_FAL_modelX11_ML,  na.action = "na.omit", weights = varIdent(form = ~ 1 | Site))

# skip varIdent, followed by REML estimation
Ca_FAL_modelX13_ML <- update(Ca_FAL_modelX11_ML,  na.action = "na.omit")
summary(Ca_FAL_modelX13_ML)
plot(Ca_FAL_modelX13_ML)
plot(Ca_FAL_modelX13_ML, Site ~ resid(.), abline=0)
plot(Ca_FAL_modelX13_ML, Type ~ resid(.), abline=0)
plot(Ca_FAL_modelX13_ML, Site ~ fitted(.), abline=0)
r.squaredGLMM(Ca_FAL_modelX13_ML)
anova(Ca_FAL_modelX13_ML)
plot(allEffects(Ca_FAL_modelX13_ML))

Ca_FAL_modelX13_REML <- update(Ca_FAL_modelX13_ML, na.action = "na.omit", method="REML")
summary(Ca_FAL_modelX13_REML)
plot(Ca_FAL_modelX13_REML)
plot(Ca_FAL_modelX13_REML, Site ~ resid(.), abline=0)
plot(Ca_FAL_modelX13_REML, Type ~ resid(.), abline=0)
plot(Ca_FAL_modelX13_REML, Site ~ fitted(.), abline=0)
plot(Ca_FAL_modelX13_REML, Type ~ fitted(.), abline=0)

anova(Ca_FAL_modelX13_REML)
r.squaredGLMM(Ca_FAL_modelX13_REML)

plot(allEffects(Ca_FAL_modelX13_REML, residuals = TRUE))

ef_Ca_FAL <- effect("Type", Ca_FAL_modelX13_REML)
summary(ef_Ca_FAL)

margCa_FAL_REML <- lsmeans(Ca_FAL_modelX13_REML, ~Type, mult.name="Type", data=SpecDatLMM_FAL)
margCa_FAL_REML_bt <- regrid(margCa_FAL_REML, transform = "response")
cld(margCa_FAL_REML_bt,
    alpha=0.05,
    Letters=letters, adjust="fdr")

emmip(Ca_FAL_modelX13_REML, ~Type, data=SpecDatLMM_FAL, CIs=TRUE)+
  geom_point(aes(x = factor(Type), y = log10(FAL_Ca)), data = SpecDatLMM_FAL, pch = 1, color = "light blue")

Ca_FAL.emm <- emmeans(Ca_FAL_modelX13_REML, ~ Type, data=SpecDatLMM_FAL, type="response")
summary(Ca_FAL.emm)
pairs(Ca_FAL.emm)
pwpp(Ca_FAL.emm)

Ca_FAL.emm.s <-contrast(regrid(Ca_FAL.emm), transform = "response")
confint(Ca_FAL.emm.s, adjust = "bonferroni")
pairs(Ca_FAL.emm.s)
pwpp(Ca_FAL.emm.s)


###### FAL Mg ######
# FAL Mg, log10
Mg_FAL_modelX1 <- formula(log10(FAL_Mg) ~ Type, data = SpecDatLMM_FAL, na.option = "na.omit")
Mg_FAL_modelX11_ML <- lme(Mg_FAL_modelX1, random = ~ 1|Site/ID, method = "ML", data = SpecDatLMM_FAL, na.action ="na.omit")
summary(Mg_FAL_modelX11_ML) 
plot(Mg_FAL_modelX11_ML)

# skip varIdent, followed by REML estimation
Mg_FAL_modelX13_ML <- update(Mg_FAL_modelX11_ML,  na.action = "na.omit")
summary(Mg_FAL_modelX13_ML)
plot(Mg_FAL_modelX13_ML)
plot(Mg_FAL_modelX13_ML, Site ~ resid(.), abline=0)
plot(Mg_FAL_modelX13_ML, Type ~ resid(.), abline=0)
plot(Mg_FAL_modelX13_ML, Site ~ fitted(.), abline=0)
r.squaredGLMM(Mg_FAL_modelX13_ML)
anova(Mg_FAL_modelX13_ML)
plot(allEffects(Mg_FAL_modelX13_ML))

Mg_FAL_modelX13_REML <- update(Mg_FAL_modelX13_ML, na.action = "na.omit", method="REML")
summary(Mg_FAL_modelX13_REML)
plot(Mg_FAL_modelX13_REML)
plot(Mg_FAL_modelX13_REML, Site ~ resid(.), abline=0)
plot(Mg_FAL_modelX13_REML, Type ~ resid(.), abline=0)
plot(Mg_FAL_modelX13_REML, Site ~ fitted(.), abline=0)
plot(Mg_FAL_modelX13_REML, Type ~ fitted(.), abline=0)

anova(Mg_FAL_modelX13_REML)
r.squaredGLMM(Mg_FAL_modelX13_REML)

plot(allEffects(Mg_FAL_modelX13_REML, residuals = TRUE))

ef_Mg_FAL <- effect("Type", Mg_FAL_modelX13_REML)
summary(ef_Mg_FAL)

margMg_FAL_REML <- lsmeans(Mg_FAL_modelX13_REML, ~Type, mult.name="Type", data=SpecDatLMM_FAL)
margMg_FAL_REML_bt <- regrid(margMg_FAL_REML, transform = "response")
cld(margMg_FAL_REML_bt,
    alpha=0.05,
    Letters=letters, adjust="fdr")

emmip(Mg_FAL_modelX13_REML, ~Type, data=SpecDatLMM_FAL, CIs=TRUE)+
  geom_point(aes(x = factor(Type), y = log10(FAL_Mg)), data = SpecDatLMM_FAL, pch = 1, color = "light blue")

Mg_FAL.emm <- emmeans(Mg_FAL_modelX13_REML, ~ Type, data=SpecDatLMM_FAL, type="response")
summary(Mg_FAL.emm)
pairs(Mg_FAL.emm)
pwpp(Mg_FAL.emm)

Mg_FAL.emm.s <-contrast(regrid(Mg_FAL.emm), transform = "response")
confint(Mg_FAL.emm.s, adjust = "bonferroni")
pairs(Mg_FAL.emm.s)
pwpp(Mg_FAL.emm.s)


###### FAL K ######
# FAL K, log10
K_FAL_modelX1 <- formula(log10(FAL_K) ~ Type, data = SpecDatLMM_FAL, na.option = "na.omit")
K_FAL_modelX11_ML <- lme(K_FAL_modelX1, random = ~ 1|Site/ID, method = "ML", data = SpecDatLMM_FAL, na.action ="na.omit")
summary(K_FAL_modelX11_ML) 
plot(K_FAL_modelX11_ML)

# skip varIdent, followed by REML estimation
K_FAL_modelX13_ML <- update(K_FAL_modelX11_ML,  na.action = "na.omit")
summary(K_FAL_modelX13_ML)
plot(K_FAL_modelX13_ML)
plot(K_FAL_modelX13_ML, Site ~ resid(.), abline=0)
plot(K_FAL_modelX13_ML, Type ~ resid(.), abline=0)
plot(K_FAL_modelX13_ML, Site ~ fitted(.), abline=0)
r.squaredGLMM(K_FAL_modelX13_ML)
anova(K_FAL_modelX13_ML)
plot(allEffects(K_FAL_modelX13_ML))

K_FAL_modelX13_REML <- update(K_FAL_modelX13_ML, na.action = "na.omit", method="REML")
summary(K_FAL_modelX13_REML)
plot(K_FAL_modelX13_REML)
plot(K_FAL_modelX13_REML, Site ~ resid(.), abline=0)
plot(K_FAL_modelX13_REML, Type ~ resid(.), abline=0)
plot(K_FAL_modelX13_REML, Site ~ fitted(.), abline=0)
plot(K_FAL_modelX13_REML, Type ~ fitted(.), abline=0)

anova(K_FAL_modelX13_REML)
r.squaredGLMM(K_FAL_modelX13_REML)

plot(allEffects(K_FAL_modelX13_REML, residuals = TRUE))

ef_K_FAL <- effect("Type", K_FAL_modelX13_REML)
summary(ef_K_FAL)

margK_FAL_REML <- lsmeans(K_FAL_modelX13_REML, ~Type, mult.name="Type", data=SpecDatLMM_FAL)
margK_FAL_REML_bt <- regrid(margK_FAL_REML, transform = "response")
cld(margK_FAL_REML_bt,
    alpha=0.05,
    Letters=letters, adjust="fdr")

emmip(K_FAL_modelX13_REML, ~Type, data=SpecDatLMM_FAL, CIs=TRUE)+
  geom_point(aes(x = factor(Type), y = log10(FAL_K)), data = SpecDatLMM_FAL, pch = 1, color = "light blue")

K_FAL.emm <- emmeans(K_FAL_modelX13_REML, ~ Type, data=SpecDatLMM_FAL, type="response")
summary(K_FAL.emm)
pairs(K_FAL.emm)
pwpp(K_FAL.emm)

K_FAL.emm.s <-contrast(regrid(K_FAL.emm), transform = "response")
confint(K_FAL.emm.s, adjust = "bonferroni")
pairs(K_FAL.emm.s)
pwpp(K_FAL.emm.s)


###### Res_Time DM ######
# Res_Time DM, log10
DM_Time_modelX1 <- formula(log10(time_DM_year) ~ Type, data = SpecDatLMM_FAL, na.option = "na.omit")
DM_Time_modelX11_ML <- lme(DM_Time_modelX1, random = ~ 1|Site/ID, method = "ML", data = SpecDatLMM_FAL, na.action ="na.omit")
summary(DM_Time_modelX11_ML) 
plot(DM_Time_modelX11_ML)

# skip varIdent, followed by REML estimation
DM_Time_modelX13_ML <- update(DM_Time_modelX11_ML,  na.action = "na.omit")
summary(DM_Time_modelX13_ML)
plot(DM_Time_modelX13_ML)
plot(DM_Time_modelX13_ML, Site ~ resid(.), abline=0)
plot(DM_Time_modelX13_ML, Type ~ resid(.), abline=0)
plot(DM_Time_modelX13_ML, Site ~ fitted(.), abline=0)
r.squaredGLMM(DM_Time_modelX13_ML)
anova(DM_Time_modelX13_ML)
plot(allEffects(DM_Time_modelX13_ML))

DM_Time_modelX13_REML <- update(DM_Time_modelX13_ML, na.action = "na.omit", method="REML")
summary(DM_Time_modelX13_REML)
plot(DM_Time_modelX13_REML)
plot(DM_Time_modelX13_REML, Site ~ resid(.), abline=0)
plot(DM_Time_modelX13_REML, Type ~ resid(.), abline=0)
plot(DM_Time_modelX13_REML, Site ~ fitted(.), abline=0)
plot(DM_Time_modelX13_REML, Type ~ fitted(.), abline=0)

anova(DM_Time_modelX13_REML)
r.squaredGLMM(DM_Time_modelX13_REML)

plot(allEffects(DM_Time_modelX13_REML, residuals = TRUE))

ef_DM_Time <- effect("Type", DM_Time_modelX13_REML)
summary(ef_DM_Time)

margDM_Time_REML <- lsmeans(DM_Time_modelX13_REML, ~Type, mult.name="Type", data=SpecDatLMM_FAL)
margDM_Time_REML_bt <- regrid(margDM_Time_REML, transform = "response")
cld(margDM_Time_REML_bt,
    alpha=0.05,
    Letters=letters, adjust="fdr")

emmip(DM_Time_modelX13_REML, ~Type, data=SpecDatLMM_FAL, CIs=TRUE)+
  geom_point(aes(x = factor(Type), y = log10(time_DM_year)), data = SpecDatLMM_FAL, pch = 1, color = "light blue")

DM_Time.emm <- emmeans(DM_Time_modelX13_REML, ~ Type, data=SpecDatLMM_FAL, type="response")
summary(DM_Time.emm)
pairs(DM_Time.emm)
pwpp(DM_Time.emm)

DM_Time.emm.s <-contrast(regrid(DM_Time.emm), transform = "response")
confint(DM_Time.emm.s, adjust = "bonferroni")
pairs(DM_Time.emm.s)
pwpp(DM_Time.emm.s)


###### Res_Time N ######
# Res_Time N, log10
N_Time_modelX1 <- formula(log10(time_N_year) ~ Type, data = SpecDatLMM_FAL, na.option = "na.omit")
N_Time_modelX11_ML <- lme(N_Time_modelX1, random = ~ 1|Site/ID, method = "ML", data = SpecDatLMM_FAL, na.action ="na.omit")
summary(N_Time_modelX11_ML) 
plot(N_Time_modelX11_ML)

# skip varIdent, followed by REML estimation
N_Time_modelX13_ML <- update(N_Time_modelX11_ML,  na.action = "na.omit")
summary(N_Time_modelX13_ML)
plot(N_Time_modelX13_ML)
plot(N_Time_modelX13_ML, Site ~ resid(.), abline=0)
plot(N_Time_modelX13_ML, Type ~ resid(.), abline=0)
plot(N_Time_modelX13_ML, Site ~ fitted(.), abline=0)
r.squaredGLMM(N_Time_modelX13_ML)
anova(N_Time_modelX13_ML)
plot(allEffects(N_Time_modelX13_ML))

N_Time_modelX13_REML <- update(N_Time_modelX13_ML, na.action = "na.omit", method="REML")
summary(N_Time_modelX13_REML)
plot(N_Time_modelX13_REML)
plot(N_Time_modelX13_REML, Site ~ resid(.), abline=0)
plot(N_Time_modelX13_REML, Type ~ resid(.), abline=0)
plot(N_Time_modelX13_REML, Site ~ fitted(.), abline=0)
plot(N_Time_modelX13_REML, Type ~ fitted(.), abline=0)

anova(N_Time_modelX13_REML)
r.squaredGLMM(N_Time_modelX13_REML)

plot(allEffects(N_Time_modelX13_REML, residuals = TRUE))

ef_N_Time <- effect("Type", N_Time_modelX13_REML)
summary(ef_N_Time)

margN_Time_REML <- lsmeans(N_Time_modelX13_REML, ~Type, mult.name="Type", data=SpecDatLMM_FAL)
margN_Time_REML_bt <- regrid(margN_Time_REML, transform = "response")
cld(margN_Time_REML_bt,
    alpha=0.05,
    Letters=letters, adjust="fdr")

emmip(N_Time_modelX13_REML, ~Type, data=SpecDatLMM_FAL, CIs=TRUE)+
  geom_point(aes(x = factor(Type), y = log10(time_N_year)), data = SpecDatLMM_FAL, pch = 1, color = "light blue")

N_Time.emm <- emmeans(N_Time_modelX13_REML, ~ Type, data=SpecDatLMM_FAL, type="response")
summary(N_Time.emm)
pairs(N_Time.emm)
pwpp(N_Time.emm)

N_Time.emm.s <-contrast(regrid(N_Time.emm), transform = "response")
confint(N_Time.emm.s, adjust = "bonferroni")
pairs(N_Time.emm.s)
pwpp(N_Time.emm.s)


###### Res_Time S ######
# Res_Time S, log10
S_Time_modelX1 <- formula(log10(time_S_year) ~ Type, data = SpecDatLMM_FAL, na.option = "na.omit")
S_Time_modelX11_ML <- lme(S_Time_modelX1, random = ~ 1|Site/ID, method = "ML", data = SpecDatLMM_FAL, na.action ="na.omit")
summary(S_Time_modelX11_ML) 
plot(S_Time_modelX11_ML)

# skip varIdent, followed by REML estimation
S_Time_modelX13_ML <- update(S_Time_modelX11_ML,  na.action = "na.omit")
summary(S_Time_modelX13_ML)
plot(S_Time_modelX13_ML)
plot(S_Time_modelX13_ML, Site ~ resid(.), abline=0)
plot(S_Time_modelX13_ML, Type ~ resid(.), abline=0)
plot(S_Time_modelX13_ML, Site ~ fitted(.), abline=0)
r.squaredGLMM(S_Time_modelX13_ML)
anova(S_Time_modelX13_ML)
plot(allEffects(S_Time_modelX13_ML))

S_Time_modelX13_REML <- update(S_Time_modelX13_ML, na.action = "na.omit", method="REML")
summary(S_Time_modelX13_REML)
plot(S_Time_modelX13_REML)
plot(S_Time_modelX13_REML, Site ~ resid(.), abline=0)
plot(S_Time_modelX13_REML, Type ~ resid(.), abline=0)
plot(S_Time_modelX13_REML, Site ~ fitted(.), abline=0)
plot(S_Time_modelX13_REML, Type ~ fitted(.), abline=0)

anova(S_Time_modelX13_REML)
r.squaredGLMM(S_Time_modelX13_REML)

plot(allEffects(S_Time_modelX13_REML, residuals = TRUE))

ef_S_Time <- effect("Type", S_Time_modelX13_REML)
summary(ef_S_Time)

margS_Time_REML <- lsmeans(S_Time_modelX13_REML, ~Type, mult.name="Type", data=SpecDatLMM_FAL)
margS_Time_REML_bt <- regrid(margS_Time_REML, transform = "response")
cld(margS_Time_REML_bt,
    alpha=0.05,
    Letters=letters, adjust="fdr")

emmip(S_Time_modelX13_REML, ~Type, data=SpecDatLMM_FAL, CIs=TRUE)+
  geom_point(aes(x = factor(Type), y = log10(time_S_year)), data = SpecDatLMM_FAL, pch = 1, color = "light blue")

S_Time.emm <- emmeans(S_Time_modelX13_REML, ~ Type, data=SpecDatLMM_FAL, type="response")
summary(S_Time.emm)
pairs(S_Time.emm)
pwpp(S_Time.emm)

S_Time.emm.s <-contrast(regrid(S_Time.emm), transform = "response")
confint(S_Time.emm.s, adjust = "bonferroni")
pairs(S_Time.emm.s)
pwpp(S_Time.emm.s)


###### Res_Time Ca ######
# Res_Time Ca, log10
Ca_Time_modelX1 <- formula(log10(time_Ca_year) ~ Type, data = SpecDatLMM_FAL, na.option = "na.omit")
Ca_Time_modelX11_ML <- lme(Ca_Time_modelX1, random = ~ 1|Site/ID, method = "ML", data = SpecDatLMM_FAL, na.action ="na.omit")
summary(Ca_Time_modelX11_ML) 
plot(Ca_Time_modelX11_ML) # show patterns

# skip varIdent, followed by REML estimation
Ca_Time_modelX13_ML <- update(Ca_Time_modelX11_ML,  na.action = "na.omit")
summary(Ca_Time_modelX13_ML)
plot(Ca_Time_modelX13_ML)
plot(Ca_Time_modelX13_ML, Site ~ resid(.), abline=0)
plot(Ca_Time_modelX13_ML, Type ~ resid(.), abline=0)
plot(Ca_Time_modelX13_ML, Site ~ fitted(.), abline=0)
r.squaredGLMM(Ca_Time_modelX13_ML)
anova(Ca_Time_modelX13_ML)
plot(allEffects(Ca_Time_modelX13_ML))

Ca_Time_modelX13_REML <- update(Ca_Time_modelX13_ML, na.action = "na.omit", method="REML")
summary(Ca_Time_modelX13_REML)
plot(Ca_Time_modelX13_REML)
plot(Ca_Time_modelX13_REML, Site ~ resid(.), abline=0)
plot(Ca_Time_modelX13_REML, Type ~ resid(.), abline=0)
plot(Ca_Time_modelX13_REML, Site ~ fitted(.), abline=0)
plot(Ca_Time_modelX13_REML, Type ~ fitted(.), abline=0)

anova(Ca_Time_modelX13_REML)
r.squaredGLMM(Ca_Time_modelX13_REML)

plot(allEffects(Ca_Time_modelX13_REML, residuals = TRUE))

ef_Ca_Time <- effect("Type", Ca_Time_modelX13_REML)
summary(ef_Ca_Time)

margCa_Time_REML <- lsmeans(Ca_Time_modelX13_REML, ~Type, mult.name="Type", data=SpecDatLMM_FAL)
margCa_Time_REML_bt <- regrid(margCa_Time_REML, transform = "response")
cld(margCa_Time_REML_bt,
    alpha=0.05,
    Letters=letters, adjust="fdr")

emmip(Ca_Time_modelX13_REML, ~Type, data=SpecDatLMM_FAL, CIs=TRUE)+
  geom_point(aes(x = factor(Type), y = log10(time_Ca_year)), data = SpecDatLMM_FAL, pch = 1, color = "light blue")

Ca_Time.emm <- emmeans(Ca_Time_modelX13_REML, ~ Type, data=SpecDatLMM_FAL, type="response")
summary(Ca_Time.emm)
pairs(Ca_Time.emm)
pwpp(Ca_Time.emm)

Ca_Time.emm.s <-contrast(regrid(Ca_Time.emm), transform = "response")
confint(Ca_Time.emm.s, adjust = "bonferroni")
pairs(Ca_Time.emm.s)
pwpp(Ca_Time.emm.s)


###### Res_Time Mg ######
# Res_Time Mg, log10
Mg_Time_modelX1 <- formula(log10(time_Mg_year) ~ Type, data = SpecDatLMM_FAL, na.option = "na.omit")
Mg_Time_modelX11_ML <- lme(Mg_Time_modelX1, random = ~ 1|Site/ID, method = "ML", data = SpecDatLMM_FAL, na.action ="na.omit")
summary(Mg_Time_modelX11_ML) 
plot(Mg_Time_modelX11_ML) # show patterns

# skip varIdent, followed by REML estimation
Mg_Time_modelX13_ML <- update(Mg_Time_modelX11_ML,  na.action = "na.omit")
summary(Mg_Time_modelX13_ML)
plot(Mg_Time_modelX13_ML)
plot(Mg_Time_modelX13_ML, Site ~ resid(.), abline=0)
plot(Mg_Time_modelX13_ML, Type ~ resid(.), abline=0)
plot(Mg_Time_modelX13_ML, Site ~ fitted(.), abline=0)
r.squaredGLMM(Mg_Time_modelX13_ML)
anova(Mg_Time_modelX13_ML)
plot(allEffects(Mg_Time_modelX13_ML))

Mg_Time_modelX13_REML <- update(Mg_Time_modelX13_ML, na.action = "na.omit", method="REML")
summary(Mg_Time_modelX13_REML)
plot(Mg_Time_modelX13_REML)
plot(Mg_Time_modelX13_REML, Site ~ resid(.), abline=0)
plot(Mg_Time_modelX13_REML, Type ~ resid(.), abline=0)
plot(Mg_Time_modelX13_REML, Site ~ fitted(.), abline=0)
plot(Mg_Time_modelX13_REML, Type ~ fitted(.), abline=0)

anova(Mg_Time_modelX13_REML)
r.squaredGLMM(Mg_Time_modelX13_REML)

plot(allEffects(Mg_Time_modelX13_REML, residuals = TRUE))

ef_Mg_Time <- effect("Type", Mg_Time_modelX13_REML)
summary(ef_Mg_Time)

margMg_Time_REML <- lsmeans(Mg_Time_modelX13_REML, ~Type, mult.name="Type", data=SpecDatLMM_FAL)
margMg_Time_REML_bt <- regrid(margMg_Time_REML, transform = "response")
cld(margMg_Time_REML_bt,
    alpha=0.05,
    Letters=letters, adjust="fdr")

emmip(Mg_Time_modelX13_REML, ~Type, data=SpecDatLMM_FAL, CIs=TRUE)+
  geom_point(aes(x = factor(Type), y = log10(time_Mg_year)), data = SpecDatLMM_FAL, pch = 1, color = "light blue")

Mg_Time.emm <- emmeans(Mg_Time_modelX13_REML, ~ Type, data=SpecDatLMM_FAL, type="response")
summary(Mg_Time.emm)
pairs(Mg_Time.emm)
pwpp(Mg_Time.emm)

Mg_Time.emm.s <-contrast(regrid(Mg_Time.emm), transform = "response")
confint(Mg_Time.emm.s, adjust = "bonferroni")
pairs(Mg_Time.emm.s)
pwpp(Mg_Time.emm.s)

###### Res_Time K ######
# Res_Time K, log10
K_Time_modelX1 <- formula(log10(time_K_year) ~ Type, data = SpecDatLMM_FAL, na.option = "na.omit")
K_Time_modelX11_ML <- lme(K_Time_modelX1, random = ~ 1|Site/ID, method = "ML", data = SpecDatLMM_FAL, na.action ="na.omit")
summary(K_Time_modelX11_ML) 
plot(K_Time_modelX11_ML)

# skip varIdent, followed by REML estimation
K_Time_modelX13_ML <- update(K_Time_modelX11_ML,  na.action = "na.omit")
summary(K_Time_modelX13_ML)
plot(K_Time_modelX13_ML)
plot(K_Time_modelX13_ML, Site ~ resid(.), abline=0)
plot(K_Time_modelX13_ML, Type ~ resid(.), abline=0)
plot(K_Time_modelX13_ML, Site ~ fitted(.), abline=0)
r.squaredGLMM(K_Time_modelX13_ML)
anova(K_Time_modelX13_ML)
plot(allEffects(K_Time_modelX13_ML))

K_Time_modelX13_REML <- update(K_Time_modelX13_ML, na.action = "na.omit", method="REML")
summary(K_Time_modelX13_REML)
plot(K_Time_modelX13_REML)
plot(K_Time_modelX13_REML, Site ~ resid(.), abline=0)
plot(K_Time_modelX13_REML, Type ~ resid(.), abline=0)
plot(K_Time_modelX13_REML, Site ~ fitted(.), abline=0)
plot(K_Time_modelX13_REML, Type ~ fitted(.), abline=0)

anova(K_Time_modelX13_REML)
r.squaredGLMM(K_Time_modelX13_REML)

plot(allEffects(K_Time_modelX13_REML, residuals = TRUE))

ef_K_Time <- effect("Type", K_Time_modelX13_REML)
summary(ef_K_Time)

margK_Time_REML <- lsmeans(K_Time_modelX13_REML, ~Type, mult.name="Type", data=SpecDatLMM_FAL)
margK_Time_REML_bt <- regrid(margK_Time_REML, transform = "response")
cld(margK_Time_REML_bt,
    alpha=0.05,
    Letters=letters, adjust="fdr")

emmip(K_Time_modelX13_REML, ~Type, data=SpecDatLMM_FAL, CIs=TRUE)+
  geom_point(aes(x = factor(Type), y = log10(time_K_year)), data = SpecDatLMM_FAL, pch = 1, color = "light blue")

K_Time.emm <- emmeans(K_Time_modelX13_REML, ~ Type, data=SpecDatLMM_FAL, type="response")
summary(K_Time.emm)
pairs(K_Time.emm)
pwpp(K_Time.emm)

K_Time.emm.s <-contrast(regrid(K_Time.emm), transform = "response")
confint(K_Time.emm.s, adjust = "bonferroni")
pairs(K_Time.emm.s)
pwpp(K_Time.emm.s)


############ Litter Model ############

###### Litter DM ######
# Litter DM, log10
DM_Lit_modelX1 <- formula(log10(DM_kg_ha_yr) ~ Type, data = SpecDatLMM_Lit, na.option = "na.omit")
DM_Lit_modelX11_ML <- lme(DM_Lit_modelX1, random = ~ 1|Site/ID, method = "ML", data = SpecDatLMM_Lit, na.action ="na.omit")
summary(DM_Lit_modelX11_ML) 
plot(DM_Lit_modelX11_ML)

# variance allowed, followed by REML estimation
DM_Lit_modelX13_ML <- update(DM_Lit_modelX11_ML,  na.action = "na.omit", weights = varIdent(form = ~ 1 | Site))
summary(DM_Lit_modelX13_ML)
plot(DM_Lit_modelX13_ML) # show patterns
plot(DM_Lit_modelX13_ML, Site ~ resid(.), abline=0)
plot(DM_Lit_modelX13_ML, Type ~ resid(.), abline=0)
plot(DM_Lit_modelX13_ML, Site ~ fitted(.), abline=0)
r.squaredGLMM(DM_Lit_modelX13_ML)
anova(DM_Lit_modelX13_ML)
plot(allEffects(DM_Lit_modelX13_ML))

DM_Lit_modelX13_REML <- update(DM_Lit_modelX13_ML, na.action = "na.omit", method="REML")
summary(DM_Lit_modelX13_REML)
plot(DM_Lit_modelX13_REML)
plot(DM_Lit_modelX13_REML, Site ~ resid(.), abline=0)
plot(DM_Lit_modelX13_REML, Type ~ resid(.), abline=0)
plot(DM_Lit_modelX13_REML, Site ~ fitted(.), abline=0)
plot(DM_Lit_modelX13_REML, Type ~ fitted(.), abline=0)

anova(DM_Lit_modelX13_REML)
r.squaredGLMM(DM_Lit_modelX13_REML)

plot(allEffects(DM_Lit_modelX13_REML, residuals = TRUE))

ef_DM_Lit <- effect("Type", DM_Lit_modelX13_REML)
summary(ef_DM_Lit)

margDM_Lit_REML <- lsmeans(DM_Lit_modelX13_REML, ~Type, mult.name="Type", data=SpecDatLMM_Lit)
margDM_Lit_REML_bt <- regrid(margDM_Lit_REML, transform = "response")
cld(margDM_Lit_REML_bt,
    alpha=0.05,
    Letters=letters, adjust="fdr")

emmip(DM_Lit_modelX13_REML, ~Type, data=SpecDatLMM_Lit, CIs=TRUE)+
  geom_point(aes(x = factor(Type), y = log10(DM_kg_ha_yr)), data = SpecDatLMM_Lit, pch = 1, color = "light blue")

DM_Lit.emm <- emmeans(DM_Lit_modelX13_REML, ~ Type, data=SpecDatLMM_Lit, type="response")
summary(DM_Lit.emm)
pairs(DM_Lit.emm)
pwpp(DM_Lit.emm)

DM_Lit.emm.s <-contrast(regrid(DM_Lit.emm), transform = "response")
confint(DM_Lit.emm.s, adjust = "bonferroni")
pairs(DM_Lit.emm.s)
pwpp(DM_Lit.emm.s)


###### Litter N ######
# Litter N, log10
N_Lit_modelX1 <- formula(log10(N_kg_ha_yr) ~ Type, data = SpecDatLMM_Lit, na.option = "na.omit")
N_Lit_modelX11_ML <- lme(N_Lit_modelX1, random = ~ 1|Site/ID, method = "ML", data = SpecDatLMM_Lit, na.action ="na.omit")
summary(N_Lit_modelX11_ML) 
plot(N_Lit_modelX11_ML)

# variance allowed, followed by REML estimation
N_Lit_modelX13_ML <- update(N_Lit_modelX11_ML,  na.action = "na.omit", weights = varIdent(form = ~ 1 | Site))
summary(N_Lit_modelX13_ML)
plot(N_Lit_modelX13_ML) 
plot(N_Lit_modelX13_ML, Site ~ resid(.), abline=0)
plot(N_Lit_modelX13_ML, Type ~ resid(.), abline=0)
plot(N_Lit_modelX13_ML, Site ~ fitted(.), abline=0)
r.squaredGLMM(N_Lit_modelX13_ML)
anova(N_Lit_modelX13_ML)
plot(allEffects(N_Lit_modelX13_ML))

N_Lit_modelX13_REML <- update(N_Lit_modelX13_ML, na.action = "na.omit", method="REML")
summary(N_Lit_modelX13_REML)
plot(N_Lit_modelX13_REML)
plot(N_Lit_modelX13_REML, Site ~ resid(.), abline=0)
plot(N_Lit_modelX13_REML, Type ~ resid(.), abline=0)
plot(N_Lit_modelX13_REML, Site ~ fitted(.), abline=0)
plot(N_Lit_modelX13_REML, Type ~ fitted(.), abline=0)

anova(N_Lit_modelX13_REML)
r.squaredGLMM(N_Lit_modelX13_REML)

plot(allEffects(N_Lit_modelX13_REML, residuals = TRUE))

ef_N_Lit <- effect("Type", N_Lit_modelX13_REML)
summary(ef_N_Lit)

margN_Lit_REML <- lsmeans(N_Lit_modelX13_REML, ~Type, mult.name="Type", data=SpecDatLMM_Lit)
margN_Lit_REML_bt <- regrid(margN_Lit_REML, transform = "response")
cld(margN_Lit_REML_bt,
    alpha=0.05,
    Letters=letters, adjust="fdr")

emmip(N_Lit_modelX13_REML, ~Type, data=SpecDatLMM_Lit, CIs=TRUE)+
  geom_point(aes(x = factor(Type), y = log10(N_kg_ha_yr)), data = SpecDatLMM_Lit, pch = 1, color = "light blue")

N_Lit.emm <- emmeans(N_Lit_modelX13_REML, ~ Type, data=SpecDatLMM_Lit, type="response")
summary(N_Lit.emm)
pairs(N_Lit.emm)
pwpp(N_Lit.emm)

N_Lit.emm.s <-contrast(regrid(N_Lit.emm), transform = "response")
confint(N_Lit.emm.s, adjust = "bonferroni")
pairs(N_Lit.emm.s)
pwpp(N_Lit.emm.s)


###### Litter S ######
# Litter S, log10
S_Lit_modelX1 <- formula(log10(S_kg_ha_yr) ~ Type, data = SpecDatLMM_Lit, na.option = "na.omit")
S_Lit_modelX11_ML <- lme(S_Lit_modelX1, random = ~ 1|Site/ID, method = "ML", data = SpecDatLMM_Lit, na.action ="na.omit")
summary(S_Lit_modelX11_ML) 
plot(S_Lit_modelX11_ML)

# variance allowed, followed by REML estimation
S_Lit_modelX13_ML <- update(S_Lit_modelX11_ML,  na.action = "na.omit", weights = varIdent(form = ~ 1 | Site))
summary(S_Lit_modelX13_ML)
plot(S_Lit_modelX13_ML) 
plot(S_Lit_modelX13_ML, Site ~ resid(.), abline=0)
plot(S_Lit_modelX13_ML, Type ~ resid(.), abline=0)
plot(S_Lit_modelX13_ML, Site ~ fitted(.), abline=0)
r.squaredGLMM(S_Lit_modelX13_ML)
anova(S_Lit_modelX13_ML)
plot(allEffects(S_Lit_modelX13_ML))

S_Lit_modelX13_REML <- update(S_Lit_modelX13_ML, na.action = "na.omit", method="REML")
summary(S_Lit_modelX13_REML)
plot(S_Lit_modelX13_REML)
plot(S_Lit_modelX13_REML, Site ~ resid(.), abline=0)
plot(S_Lit_modelX13_REML, Type ~ resid(.), abline=0)
plot(S_Lit_modelX13_REML, Site ~ fitted(.), abline=0)
plot(S_Lit_modelX13_REML, Type ~ fitted(.), abline=0)

anova(S_Lit_modelX13_REML)
r.squaredGLMM(S_Lit_modelX13_REML)

plot(allEffects(S_Lit_modelX13_REML, residuals = TRUE))

ef_S_Lit <- effect("Type", S_Lit_modelX13_REML)
summary(ef_S_Lit)

margS_Lit_REML <- lsmeans(S_Lit_modelX13_REML, ~Type, mult.name="Type", data=SpecDatLMM_Lit)
margS_Lit_REML_bt <- regrid(margS_Lit_REML, transform = "response")
cld(margS_Lit_REML_bt,
    alpha=0.05,
    Letters=letters, adjust="fdr")

emmip(S_Lit_modelX13_REML, ~Type, data=SpecDatLMM_Lit, CIs=TRUE)+
  geom_point(aes(x = factor(Type), y = log10(S_kg_ha_yr)), data = SpecDatLMM_Lit, pch = 1, color = "light blue")

S_Lit.emm <- emmeans(S_Lit_modelX13_REML, ~ Type, data=SpecDatLMM_Lit, type="response")
summary(S_Lit.emm)
pairs(S_Lit.emm)
pwpp(S_Lit.emm)

S_Lit.emm.s <-contrast(regrid(S_Lit.emm), transform = "response")
confint(S_Lit.emm.s, adjust = "bonferroni")
pairs(S_Lit.emm.s)
pwpp(S_Lit.emm.s)


###### Litter Ca ######
# Litter Ca, log10
Ca_Lit_modelX1 <- formula(log10(Ca_kg_ha_yr) ~ Type, data = SpecDatLMM_Lit, na.option = "na.omit")
Ca_Lit_modelX11_ML <- lme(Ca_Lit_modelX1, random = ~ 1|Site/ID, method = "ML", data = SpecDatLMM_Lit, na.action ="na.omit")
summary(Ca_Lit_modelX11_ML) 
plot(Ca_Lit_modelX11_ML)

# variance allowed, followed by REML estimation
Ca_Lit_modelX13_ML <- update(Ca_Lit_modelX11_ML,  na.action = "na.omit", weights = varIdent(form = ~ 1 | Site))
summary(Ca_Lit_modelX13_ML)
plot(Ca_Lit_modelX13_ML)
plot(Ca_Lit_modelX13_ML, Site ~ resid(.), abline=0)
plot(Ca_Lit_modelX13_ML, Type ~ resid(.), abline=0)
plot(Ca_Lit_modelX13_ML, Site ~ fitted(.), abline=0)
r.squaredGLMM(Ca_Lit_modelX13_ML)
anova(Ca_Lit_modelX13_ML)
plot(allEffects(Ca_Lit_modelX13_ML))

Ca_Lit_modelX13_REML <- update(Ca_Lit_modelX13_ML, na.action = "na.omit", method="REML")
summary(Ca_Lit_modelX13_REML)
plot(Ca_Lit_modelX13_REML)
plot(Ca_Lit_modelX13_REML, Site ~ resid(.), abline=0)
plot(Ca_Lit_modelX13_REML, Type ~ resid(.), abline=0)
plot(Ca_Lit_modelX13_REML, Site ~ fitted(.), abline=0)
plot(Ca_Lit_modelX13_REML, Type ~ fitted(.), abline=0)

anova(Ca_Lit_modelX13_REML)
r.squaredGLMM(Ca_Lit_modelX13_REML)

plot(allEffects(Ca_Lit_modelX13_REML, residuals = TRUE))

ef_Ca_Lit <- effect("Type", Ca_Lit_modelX13_REML)
summary(ef_Ca_Lit)

margCa_Lit_REML <- lsmeans(Ca_Lit_modelX13_REML, ~Type, mult.name="Type", data=SpecDatLMM_Lit)
margCa_Lit_REML_bt <- regrid(margCa_Lit_REML, transform = "response")
cld(margCa_Lit_REML_bt,
    alpha=0.05,
    Letters=letters, adjust="fdr")

emmip(Ca_Lit_modelX13_REML, ~Type, data=SpecDatLMM_Lit, CIs=TRUE)+
  geom_point(aes(x = factor(Type), y = log10(Ca_kg_ha_yr)), data = SpecDatLMM_Lit, pch = 1, color = "light blue")

Ca_Lit.emm <- emmeans(Ca_Lit_modelX13_REML, ~ Type, data=SpecDatLMM_Lit, type="response")
summary(Ca_Lit.emm)
pairs(Ca_Lit.emm)
pwpp(Ca_Lit.emm)

Ca_Lit.emm.s <-contrast(regrid(Ca_Lit.emm), transform = "response")
confint(Ca_Lit.emm.s, adjust = "bonferroni")
pairs(Ca_Lit.emm.s)
pwpp(Ca_Lit.emm.s)


###### Litter Mg ######
# Litter Mg, log10
Mg_Lit_modelX1 <- formula(log10(Mg_kg_ha_yr) ~ Type, data = SpecDatLMM_Lit, na.option = "na.omit")
Mg_Lit_modelX11_ML <- lme(Mg_Lit_modelX1, random = ~ 1|Site/ID, method = "ML", data = SpecDatLMM_Lit, na.action ="na.omit")
summary(Mg_Lit_modelX11_ML) 
plot(Mg_Lit_modelX11_ML)

# variance allowed, followed by REML estimation
Mg_Lit_modelX13_ML <- update(Mg_Lit_modelX11_ML,  na.action = "na.omit", weights = varIdent(form = ~ 1 | Site))
summary(Mg_Lit_modelX13_ML)
plot(Mg_Lit_modelX13_ML)
plot(Mg_Lit_modelX13_ML, Site ~ resid(.), abline=0)
plot(Mg_Lit_modelX13_ML, Type ~ resid(.), abline=0)
plot(Mg_Lit_modelX13_ML, Site ~ fitted(.), abline=0)
r.squaredGLMM(Mg_Lit_modelX13_ML)
anova(Mg_Lit_modelX13_ML)
plot(allEffects(Mg_Lit_modelX13_ML))

Mg_Lit_modelX13_REML <- update(Mg_Lit_modelX13_ML, na.action = "na.omit", method="REML")
summary(Mg_Lit_modelX13_REML)
plot(Mg_Lit_modelX13_REML)
plot(Mg_Lit_modelX13_REML, Site ~ resid(.), abline=0)
plot(Mg_Lit_modelX13_REML, Type ~ resid(.), abline=0)
plot(Mg_Lit_modelX13_REML, Site ~ fitted(.), abline=0)
plot(Mg_Lit_modelX13_REML, Type ~ fitted(.), abline=0)

anova(Mg_Lit_modelX13_REML)
r.squaredGLMM(Mg_Lit_modelX13_REML)

plot(allEffects(Mg_Lit_modelX13_REML, residuals = TRUE))

ef_Mg_Lit <- effect("Type", Mg_Lit_modelX13_REML)
summary(ef_Mg_Lit)

margMg_Lit_REML <- lsmeans(Mg_Lit_modelX13_REML, ~Type, mult.name="Type", data=SpecDatLMM_Lit)
margMg_Lit_REML_bt <- regrid(margMg_Lit_REML, transform = "response")
cld(margMg_Lit_REML_bt,
    alpha=0.05,
    Letters=letters, adjust="fdr")

emmip(Mg_Lit_modelX13_REML, ~Type, data=SpecDatLMM_Lit, CIs=TRUE)+
  geom_point(aes(x = factor(Type), y = log10(Mg_kg_ha_yr)), data = SpecDatLMM_Lit, pch = 1, color = "light blue")

Mg_Lit.emm <- emmeans(Mg_Lit_modelX13_REML, ~ Type, data=SpecDatLMM_Lit, type="response")
summary(Mg_Lit.emm)
pairs(Mg_Lit.emm)
pwpp(Mg_Lit.emm)

Mg_Lit.emm.s <-contrast(regrid(Mg_Lit.emm), transform = "response")
confint(Mg_Lit.emm.s, adjust = "bonferroni")
pairs(Mg_Lit.emm.s)
pwpp(Mg_Lit.emm.s)


###### Litter K ######
# Litter K, log10
K_Lit_modelX1 <- formula(log10(K_kg_ha_yr) ~ Type, data = SpecDatLMM_Lit, na.option = "na.omit")
K_Lit_modelX11_ML <- lme(K_Lit_modelX1, random = ~ 1|Site/ID, method = "ML", data = SpecDatLMM_Lit, na.action ="na.omit")
summary(K_Lit_modelX11_ML) 
plot(K_Lit_modelX11_ML)

# variance allowed, followed by REML estimation
K_Lit_modelX13_ML <- update(K_Lit_modelX11_ML,  na.action = "na.omit", weights = varIdent(form = ~ 1 | Site))
summary(K_Lit_modelX13_ML)
plot(K_Lit_modelX13_ML) 
plot(K_Lit_modelX13_ML, Site ~ resid(.), abline=0)
plot(K_Lit_modelX13_ML, Type ~ resid(.), abline=0)
plot(K_Lit_modelX13_ML, Site ~ fitted(.), abline=0)
r.squaredGLMM(K_Lit_modelX13_ML)
anova(K_Lit_modelX13_ML)
plot(allEffects(K_Lit_modelX13_ML))

K_Lit_modelX13_REML <- update(K_Lit_modelX13_ML, na.action = "na.omit", method="REML")
summary(K_Lit_modelX13_REML)
plot(K_Lit_modelX13_REML)
plot(K_Lit_modelX13_REML, Site ~ resid(.), abline=0)
plot(K_Lit_modelX13_REML, Type ~ resid(.), abline=0)
plot(K_Lit_modelX13_REML, Site ~ fitted(.), abline=0)
plot(K_Lit_modelX13_REML, Type ~ fitted(.), abline=0)

anova(K_Lit_modelX13_REML)
r.squaredGLMM(K_Lit_modelX13_REML)

plot(allEffects(K_Lit_modelX13_REML, residuals = TRUE))

ef_K_Lit <- effect("Type", K_Lit_modelX13_REML)
summary(ef_K_Lit)

margK_Lit_REML <- lsmeans(K_Lit_modelX13_REML, ~Type, mult.name="Type", data=SpecDatLMM_Lit)
margK_Lit_REML_bt <- regrid(margK_Lit_REML, transform = "response")
cld(margK_Lit_REML_bt,
    alpha=0.05,
    Letters=letters, adjust="fdr")

emmip(K_Lit_modelX13_REML, ~Type, data=SpecDatLMM_Lit, CIs=TRUE)+
  geom_point(aes(x = factor(Type), y = log10(K_kg_ha_yr)), data = SpecDatLMM_Lit, pch = 1, color = "light blue")

K_Lit.emm <- emmeans(K_Lit_modelX13_REML, ~ Type, data=SpecDatLMM_Lit, type="response")
summary(K_Lit.emm)
pairs(K_Lit.emm)
pwpp(K_Lit.emm)

K_Lit.emm.s <-contrast(regrid(K_Lit.emm), transform = "response")
confint(K_Lit.emm.s, adjust = "bonferroni")
pairs(K_Lit.emm.s)
pwpp(K_Lit.emm.s)


#####################################  t-Test Dir/DifRad pathway  ###################################
library (car)
library(readxl)
DataT <- read_excel("DataT.xlsx", col_types = c("text", 
                                                "numeric", "numeric"))
View(DataT)

## levene equality of variance
leveneTest(DifBe_MJm2yr ~ Type, DataT) # var equal
leveneTest(DirBe_MJm2yr ~ Type, DataT) # var not equal

## t-Test
t.test(DifBe_MJm2yr~Type, data = DataT, var.equal = TRUE)
t.test(DirBe_MJm2yr~Type, data = DataT, var.equal = FALSE)
